model VBelt "Contact model for a VBelt" 
 extends Interfaces.PartialContactModel;
  import Belts.Functions.absVec;
  annotation (Documentation(info="<HTML>
<p>
This model element describes the contact model for a VBelt.
Its similar to the contact model for the flat belt <br> 
except that the friction coefficient is multiplied with the factor 1/sin(grooveangle/2).<br>
</HTML>
"), Diagram,
    Icon(
    Ellipse(extent=[-60,60; 60,-60], style(
          color=0,
          rgbcolor={0,0,0},
          fillColor=30,
          rgbfillColor={215,215,215})),
    Ellipse(extent=[-56,56; 56,-56], style(
          color=0,
          rgbcolor={0,0,0},
          pattern=3))));
  
 parameter Modelica.SIunits.CoefficientOfFriction mu=Belts.Defaults.Mu 
    "friction coefficient"                                                                     annotation(Dialog(tab="Contact model"));
 parameter Belts.Types.GrooveAngle grooveAngle = Belts.Defaults.grooveAngle annotation(Dialog(tab="Contact model"));
  
 Modelica.SIunits.Torque eytelweinTorque;
 Modelica.SIunits.Mass Mass;
 Modelica.SIunits.Mass TotalMass;
  
 Modelica.Mechanics.Rotational.Clutch clutch(fn_max=2) 
    annotation (extent=[70,60; 90,40], rotation=90);
 Modelica.Blocks.Sources.RealExpression realExpression(y=eytelweinTorque) 
    annotation (extent=[50,0; 70,20], rotation=90);
 SlippingBeltMass slippingBeltMass(
    J=TotalMass*(pulleyDiameter/2)^2,
    w_start=slip_w_start) 
    annotation (extent=[20,60; 40,80], rotation=0);
  
protected 
 model SlippingBeltMass 
    import SI = Modelica.SIunits;
    import Modelica.Mechanics.Rotational.Types.Init;
 extends Modelica.Mechanics.Rotational.Interfaces.Rigid;
 parameter Real w_start;
 SI.Inertia J( min=0)=1 "moment of inertia";
 SI.Velocity w(start=w_start) "angular velocity";
 SI.AngularAcceleration a "angular acceleration";
 equation 
 w = der(phi);
 a = der(w);
 J*a = flange_a.tau + flange_b.tau;
 annotation (Diagram(Rectangle(extent=[-60,10; 60,0], style(
           color=0,
           rgbcolor={0,0,0},
           arrow=1,
           fillPattern=10)), Line(points=[-40,-20; 40,-20], style(
           color=0,
           rgbcolor={0,0,0},
           arrow=3))),Icon(
       Rectangle(extent=[-60,10; 60,-8], style(
           color=0,
           rgbcolor={0,0,0},
           arrow=1,
           fillPattern=10)),
       Line(points=[-60,0; -100,0], style(color=0, rgbcolor={0,0,0})),
       Line(points=[100,0; 60,0], style(color=0, rgbcolor={0,0,0})),
     Text(
       extent=[-60,-20; 60,-40],
       string="%name",
       style(color=0))));
 end SlippingBeltMass;
  
equation 
 Mass = (spanLength_a + spanLength_b) * beltMass / 2;
 TotalMass =  Mass + (WALength * beltMass);
  
 eytelweinTorque= if  absVec(spanForceVec_a)< absVec(spanForceVec_b) then 
                    absVec(spanForceVec_a)*exp(mu*1/sin(grooveAngle/2)*wrapAngle)*pulleyDiameter/2 else 
                    absVec(spanForceVec_b)*exp(mu*1/sin(grooveAngle/2)*wrapAngle)*pulleyDiameter/2;
  
  connect(clutch.f_normalized, realExpression.y) annotation (points=[69,50; 60,
        50; 60,21], style(color=74, rgbcolor={0,0,127}));
  connect(clutch.flange_a, slippingBeltMass.flange_b) annotation (points=[80,60;
        80,70; 40,70], style(color=0, rgbcolor={0,0,0}));
  connect(flangeBelt, slippingBeltMass.flange_a) 
    annotation (points=[-20,70; 20,70], style(color=0, rgbcolor={0,0,0}));
  connect(flangePulley, clutch.flange_b) annotation (points=[40,-80; 80,-80; 80,
        40], style(color=0, rgbcolor={0,0,0}));
end VBelt;
