package Defaults "Default settings of the Belts library."
import SI = Modelica.SIunits;


  annotation (preferedView="info", Documentation(info="<html>
<p>
This package contains constants used as default setting
in the Belts library. Values set in this package are standard 
values for passenger car accessory drives.
</p>
</html>"));


  extends Modelica.Icons.Library;
  constant Belts.Types.BeltStiffness EA = 190000 
  "Default Longitudinal belt stiffness";
  constant Belts.Types.BeltMass mr = 0.1 "Default Belt mass per meter";
  constant Belts.Types.SpanForce F0 = 350 "Default Preload";
  constant Modelica.SIunits.Length width = 0.02 "Default Belt width";
  constant Belts.Types.BeltDamping d_l = 1 
  "Default Longitudinal belt damping coefficient";
  constant Belts.Types.BeltDamping d_t = 0.1 
  "Deafault Transversal belt damping coefficient";
  constant Modelica.SIunits.Position z = 0.0 
  "Default Z-koordinate of belt drive";
  constant Modelica.SIunits.Diameter diameter = 0.06 "Default Pulley diameter";
  constant Modelica.SIunits.Mass Mass = 0.15 "Default Pulley mass";
  constant Modelica.SIunits.Inertia Inertia = 0.003 "Default Pulley inertia";
  constant Modelica.Mechanics.MultiBody.Types.SpecularCoefficient 
  specularCoefficient =    0.0 "Default Reflection of ambient light";
  constant Modelica.Mechanics.MultiBody.Types.Color PulleyColor = {100, 100, 100} 
  "Default Pulley color";
  constant Belts.Types.ForceScalingFactor hubloadScale = 0.0002 
  "Default Scaling factor for hubload vector";
  constant Modelica.SIunits.Diameter hubloadDiameter = 0.005 
  "Default Diameter of arrow representing the hubload vector";
  constant Modelica.Mechanics.MultiBody.Types.Color hubloadColor = {0, 255, 0} 
  "Default Color of arrow representing the hubload vector";
  constant Belts.Types.TorqueScalingFactor torqueScale = 0.005 
  "Default Scaling factor for torque vector";
  constant Modelica.SIunits.Diameter torqueDiameter = 0.005 
  "Default Diameter of arrow representing the hubload vector";
  constant Modelica.Mechanics.MultiBody.Types.Color positiveTorqueColor = {0, 255, 0} 
  "Default Color of arrow representing a positive torque vector";
  constant Modelica.Mechanics.MultiBody.Types.Color negativeTorqueColor = {255, 0, 0} 
  "Default Color of arrow representing a negative torque vector";
  constant Integer modeShapes = 3 
  "Default Number of modes shapes for transversal vibration";
  constant Belts.Types.ForceScalingFactor spanForceScale = 0.0002 
  "Default Scaling factor for span force vector";
  constant Modelica.Mechanics.MultiBody.Types.Color spanForceColor = {0, 0, 255} 
  "Default Color of arrow representing the span force vector";
  constant Modelica.SIunits.Diameter spanForceDiameter = 0.005 
  "Default Diameter of arrow representing the span force vector";
  constant Modelica.SIunits.CoefficientOfFriction Mu = 0.9 
  "Default Friction coefficient";
  constant Modelica.SIunits.Length InitialElongation = 0.001 
  "Default initial elongation for every mode shape";
  constant Modelica.SIunits.Length height = 0.005 "Default belt height";
  constant Modelica.SIunits.Angle grooveAngle = 0.7 "Default groove angle";
  constant Modelica.Mechanics.MultiBody.Types.Color pulleyMarkerColor = {0,0,0} 
  "Default color of cylinder representing the pulley position marker";
  constant Modelica.Mechanics.MultiBody.Types.Color beltMarkerColor = {255,0,0} 
  "Default color of cylinder representing the belt position marker";
  constant Modelica.SIunits.Diameter markerDiameter = 0.005 
  "Default diameter of cylinder representing the positionmarkers on the pulley";
end Defaults;
