model DoubleContact "Demo drive with a double contact pulley" 
  
  annotation (Documentation(info="<HTML>
<p>
 Example for a double belt-pulley contact at the middle pulley. The LeftPulley is charged with an initial angular velocity of 50 rad/s. The
 RightPulley is damped by a rotational damper which has a rotational damping constant of 0.03 Nms/rad. <br>
 For simulation you can either select the simulation button <IMG SRC=\"../Pics/simulation.PNG\"> or <b>Commands</b> and <b>span forces in 
 the belt in [N]</b>. <br>
 After the simulation of the model, it's possible to display the span forces, the rotational angle of the pulleys and the rotational velocities 
 of the pulleys automatically by selecting <b>Commands</b> and <b>span forces in the belt in [N]</b>, and so on. 
 
</p>
<p>
  <IMG SRC=\"../Pics/DoubleContactExample.PNG\"
</p>
</HTML>
"), Diagram,
    Commands(
      executeCall(ensureSimulated=true) = plot({"span_DCP_RP.SpanForce",
        "span_LP_DCP.SpanForce","span_DCP_LP.SpanForce","span_RP_DCP.SpanForce"}) 
        "span forces in the belt in [N]",
      executeCall(ensureSimulated=true) = plot({"LeftPulley.pulleyInertia.phi",
        "DoubleContactPulley1.pulleyInertia.phi",
        "DoubleContactPulley2.pulleyInertia.phi",
        "RightPulley.pulleyInertia.phi"}) 
        "rotational angle of the pulley in [rad]",
      executeCall(ensureSimulated=true) = plot({"LeftPulley.pulleyInertia.w",
        "DoubleContactPulley1.pulleyInertia.w",
        "DoubleContactPulley2.pulleyInertia.w","RightPulley.pulleyInertia.w"}) 
        "rotational velocity of the pulleys in [rad/s]"));
  extends Modelica.Icons.Example;
  ModelElements.FixedPulley LeftPulley(
    diameter=0.05,
    animateHubloads=true,
    animateTorque=false,
    position={0.4,0},
    redeclare Belts.Visualizers.Pulleys.PulleyBoard pulleyShape,
    redeclare model ContactModel = Belts.ContactModels.VBelt,
    showMarker=true,
    w_start=50)         annotation (extent=[-80,0; -60,20]);
  ModelElements.FixedPulley DoubleContactPulley1(
    animateTorque=false,
    diameter=0.3,
    animateHubloads=false,
    redeclare Belts.Visualizers.Pulleys.PulleyBoard pulleyShape,
    redeclare model ContactModel = Belts.ContactModels.VBelt,
    showMarker=true) 
                  annotation (extent=[-10,12; 10,32]);
  ModelElements.FixedPulley DoubleContactPulley2(
    showPulley=false,
    diameter=0.3,
    redeclare Belts.Visualizers.Pulleys.BasicPulley pulleyShape,
    redeclare model ContactModel = Belts.ContactModels.VBelt,
    showMarker=true) 
                   annotation (extent=[-10,-10; 10,10]);
 ModelElements.FixedPulley RightPulley(
    diameter=0.05,
    animateHubloads=true,
    animateTorque=false,
    position={-0.5,0},
    redeclare Belts.Visualizers.Pulleys.PulleyBoard pulleyShape,
    redeclare model ContactModel = Belts.ContactModels.VBelt,
    showMarker=true) 
    annotation (extent=[60,0; 80,20]);
  ModelElements.WrapAngle wrapAngle_LP(redeclare 
      Belts.Visualizers.BeltShapes.VBelt beltShape) 
    annotation (extent=[-90,0; -70,20],  rotation=45);
  ModelElements.WrapAngle wrapAngle_DCP_1(redeclare 
      Belts.Visualizers.BeltShapes.VBelt beltShape) 
    annotation (extent=[10,50; -10,30],rotation=135);
  ModelElements.WrapAngle wrapAngle_RP(redeclare 
      Belts.Visualizers.BeltShapes.RoundEdge beltShape) 
    annotation (extent=[70,0; 90,20], rotation=225);
  ModelElements.WrapAngle wrapAngle_DCP_2(redeclare 
      Belts.Visualizers.BeltShapes.VBelt beltShape) 
    annotation (extent=[10,-10; -10,-30],
                                        rotation=315);
  
  ModelElements.Span span_DCP_RP(
    animateSpanForces=false,
    modeShapes=3,
    animationPoints=20,
    redeclare Belts.Visualizers.BeltShapes.VBelt beltShape) 
                          annotation (extent=[63,-23; 83,-3],  rotation=45);
  ModelElements.Span span_LP_DCP(
    animateSpanForces=false,
    modeShapes=3,
    animationPoints=20,
    redeclare Belts.Visualizers.BeltShapes.VBelt beltShape) 
                           annotation (extent=[-83,-23; -63,-3],  rotation=315);
  ModelElements.Span span_DCP_LP(
    animateSpanForces=false,
    modeShapes=3,
    animationPoints=20,
    redeclare Belts.Visualizers.BeltShapes.VBelt beltShape) 
                           annotation (extent=[-83,23; -63,43], rotation=225);
  ModelElements.Span span_RP_DCP(
    animateSpanForces=false,
    modeShapes=3,
    animationPoints=20,
    redeclare Belts.Visualizers.BeltShapes.VBelt beltShape) 
                           annotation (extent=[63,23; 83,43], rotation=135);
  
  annotation (Diagram);
  inner Modelica.Mechanics.MultiBody.World world(animateWorld=false,
      animateGravity=false) annotation (extent=[-94,86; -84,96]);
  
  Modelica.Mechanics.Rotational.Damper damper(d=0.03) 
    annotation (extent=[42,-48; 62,-28], rotation=270);
  Modelica.Mechanics.Rotational.Fixed fixed annotation (extent=[42,-64; 62,-44]);
equation 
  connect(span_DCP_RP.spanConnector_b, wrapAngle_RP.spanConnector_a) 
                                                            annotation (points=[80.0711,
        -5.92893; 80,-5.92893; 80,5.75736],
                                      style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(wrapAngle_RP.spanConnector_b, span_RP_DCP.spanConnector_a) 
                                                             annotation (points=[80,
        14.2426; 80,25.9289; 80.0711,25.9289],
                                   style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(span_RP_DCP.spanConnector_b, wrapAngle_DCP_1.spanConnector_a) 
                                                             annotation (points=[65.9289,
        40.0711; 17.5858,40.0711; 17.5858,40; 4.24264,40],
                            style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(span_LP_DCP.spanConnector_b, wrapAngle_DCP_2.spanConnector_a) 
                                                             annotation (points=[-65.9289,
        -20.0711; -28.5858,-20.0711; -28.5858,-20; -4.24264,-20],
                                                  style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(wrapAngle_DCP_2.spanConnector_b, span_DCP_RP.spanConnector_a) 
                                                            annotation (points=[4.24264,
        -20; 18.5858,-20; 18.5858,-20.0711; 65.9289,-20.0711],
                                               style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(DoubleContactPulley1.flange_b, DoubleContactPulley2.flange_b) 
    annotation (points=[0,22; -14,22; -14,0; 0,0],   style(color=0, rgbcolor={0,
          0,0}));
  connect(DoubleContactPulley2.wrapAngleConnector_a, wrapAngle_DCP_2.wrapAngleConnector_b) 
    annotation (points=[-4.2,4.2; -4,4; -4,-14; 0,-14; 0,-21.5556; 0.141421,
        -21.5556],                                                       style(
      color=0,
      rgbcolor={50,50,50},
      pattern=3,
      thickness=2));
  connect(span_LP_DCP.spanConnector_a, wrapAngle_LP.spanConnector_b) 
                                                            annotation (points=[-80.0711,
        -5.92893; -80,-5.92893; -80,5.75736],
                                         style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(DoubleContactPulley1.wrapAngleConnector_a, wrapAngle_DCP_1.wrapAngleConnector_b) 
    annotation (points=[-4.2,26.2; -4.2,37.1; -0.141421,37.1; -0.141421,41.5556],
      style(
      color=0,
      rgbcolor={50,50,50},
      pattern=3,
      thickness=2));
  connect(LeftPulley.wrapAngleConnector_a, wrapAngle_LP.wrapAngleConnector_b) 
    annotation (points=[-74.2,14.2; -78,14.2; -78,10; -81.5556,10; -81.5556,
        9.85858],
      style(
      color=0,
      rgbcolor={50,50,50},
      pattern=3,
      thickness=2));
  connect(RightPulley.wrapAngleConnector_a, wrapAngle_RP.wrapAngleConnector_b) 
    annotation (points=[65.8,14.2; 70,14; 74,14; 74,10.1414; 81.5556,10.1414],
      style(
      color=0,
      rgbcolor={50,50,50},
      pattern=3,
      thickness=2));
  connect(span_DCP_LP.spanConnector_b, wrapAngle_LP.spanConnector_a) 
                                                            annotation (points=[-80.0711,
        25.9289; -80,25.9289; -80,14.2426],
                                       style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(wrapAngle_DCP_1.spanConnector_b, span_DCP_LP.spanConnector_a) 
    annotation (points=[-4.24264,40; -40.0858,40; -40.0858,40.0711; -65.9289,
        40.0711], style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(RightPulley.flange_b, damper.flange_a) annotation (points=[70,10; 52,
        10; 52,-28], style(color=0, rgbcolor={0,0,0}));
  connect(fixed.flange_b, damper.flange_b) 
    annotation (points=[52,-54; 52,-48], style(color=0, rgbcolor={0,0,0}));
end DoubleContact;
