model FloatingPulleys 
  "Advanced model with two floating pulleys connected by a spring" 
  annotation (Documentation(info="<HTML>
<p>
 Advanced example for the use of free pulleys. The two free pulleys are connected by a linear spring. The vibration of the drive is caused by 
 the initial position of the free pulleys and the pretension of the connecting spring. <br>
 For simulation you can either select the simulation button <IMG SRC=\"../Pics/simulation.PNG\"> or <b>Commands</b> and <b>span forces in 
 the belt in [N]</b>. <br>
 After the simulation of the model, it's possible to display the rotational velocities, span forces and force in the spring 
 automatically by selecting <b>Commands </b> and <b>rotational velocity of the pulleys in [rad] </b>, and so on. For an appropriate animation 
 speed select <b>Speed: 0.1</b> in the animation speed pull down menu of the <b>Simulation tab</b>. If you want to animate the belt drive
 continuously select <b>Animation</b>, <b>Setup</b> and check the box in front of <b>Run animation continuously</b>.
</p>
<p>
  <IMG SRC=\"../Pics/FloatingPulleysExample.PNG\"
</p>
</HTML>
"), Diagram,
    experiment(StopTime=0.2107),
    Commands(
      executeCall(ensureSimulated=true) = plot({"LeftPulley.pulleyInertia.w",
        "RightPulley.pulleyInertia.w","upperPulley.pulleyInertia.w",
        "lowerPulley.pulleyInertia.w"}) 
        "rotational velocity of the pulleys in [rad/s]",
      executeCall(ensureSimulated=true) = plot({"spanLower2Right.SpanForce",
        "spanRight2Upper.SpanForce","spanUpper2Left.SpanForce",
        "spanLeft2Lower.SpanForce"}) "span forces in the belt in [N]",
      executeCall=plot({"spring.spring.f"}) "force of the spring in [N]"),
    experimentSetupOutput);
  
  extends Modelica.Icons.Example;
  annotation (Diagram,                       experiment(StopTime=0.47));
  inner Modelica.Mechanics.MultiBody.World world(
    g=0,
    animateWorld=false,
    animateGravity=false,
    enableAnimation=true) 
    annotation (extent=[-94,86; -84,96]);
  ModelElements.FixedPulley LeftPulley(diameter=0.3,
    specularCoefficient=0,
    color={100,100,100},
    hubloadColor={0,255,0},
    torqueScale=0.1,
    animateTorque=false,
    showPulley=true,
    animateHubloads=true,
    position={-0.75,0},
    redeclare Belts.Visualizers.Pulleys.PulleyHub pulleyShape,
    showMarker=true) 
    annotation (extent=[-80,2; -60,22],    rotation=0);
  ModelElements.FixedPulley RightPulley(
    diameter=0.3,
    specularCoefficient=0,
    color={100,100,100},
    hubloadColor={0,255,0},
    animateTorque=false,
        animateHubloads=true,
    position={0.75,0},
    redeclare Belts.Visualizers.Pulleys.PulleyHub pulleyShape,
    showMarker=true) 
    annotation (extent=[80,2; 60,22], rotation=0);
  ModelElements.WrapAngle wrapAngleLeftPulley(redeclare 
      Belts.Visualizers.BeltShapes.DPK beltShape, width=3*Belts.Defaults.width) 
    annotation (extent=[-90,0; -70,20],   rotation=45);
  ModelElements.WrapAngle wrapAngleRightPulley(redeclare 
      Belts.Visualizers.BeltShapes.DPK beltShape, width=3*Belts.Defaults.width) 
    annotation (extent=[70,0; 90,20], rotation=225);
  ModelElements.Span spanUpper2Left(
    animateSpanForces=false,
    redeclare Belts.Visualizers.BeltShapes.DPK beltShape,
    modeShapes=0,
    animationPoints=2,
    EA=Belts.Defaults.EA,
    width=3*Belts.Defaults.width,
    F0=1200) 
    annotation (extent=[-83,23; -63,43],rotation=225);
  ModelElements.Span spanLeft2Lower(
    animateSpanForces=false,
    redeclare Belts.Visualizers.BeltShapes.DPK beltShape,
    modeShapes=0,
    animationPoints=2,
    EA=Belts.Defaults.EA,
    width=3*Belts.Defaults.width,
    F0=1200) 
    annotation (extent=[-83,-23; -63,-3], rotation=315);
  ModelElements.WrapAngle wrapAngleUpperPulley(redeclare 
      Belts.Visualizers.BeltShapes.DPK beltShape, width=3*Belts.Defaults.width) 
    annotation (extent=[-10,50; 10,30],rotation=315);
  ModelElements.WrapAngle wrapAngleLowerPulley(redeclare 
      Belts.Visualizers.BeltShapes.DPK beltShape, width=3*Belts.Defaults.width) 
    annotation (extent=[-10,-10; 10,-30],rotation=135);
  ModelElements.Span spanLower2Right(
    animateSpanForces=false,
    redeclare Belts.Visualizers.BeltShapes.DPK beltShape,
    modeShapes=0,
    animationPoints=2,
    EA=Belts.Defaults.EA,
    width=3*Belts.Defaults.width,
    F0=1200) 
    annotation (extent=[63,-23; 83,-3],  rotation=45);
  ModelElements.Span spanRight2Upper(
    spanForceColor={0,0,255},
    animateSpanForces=false,
    redeclare Belts.Visualizers.BeltShapes.DPK beltShape,
    modeShapes=0,
    animationPoints=2,
    EA=Belts.Defaults.EA,
    width=3*Belts.Defaults.width,
    F0=1200) 
    annotation (extent=[63,23; 83,43], rotation=135);
  Modelica.Mechanics.MultiBody.Forces.Spring spring(
    m=30,
    massColor={0,0,0},
    showMass=false,
    animation=true,
    s_unstretched=-0.5,
    c=400) 
    annotation (extent=[-40,0; -20,20],rotation=90);
  ModelElements.FreePulley upperPulley(
    mass=5,
    inside=false,
    useInitialPosition=true,
    initialPosition={0,0.04,0},
    redeclare Belts.Visualizers.Pulleys.PulleyBoard pulleyShape,
    animateTorque=false,
    showMarker=true) 
    annotation (extent=[-10,42; 10,62], rotation=180);
  ModelElements.FreePulley lowerPulley(
    mass=5,
    inside=false,
    useInitialPosition=true,
    redeclare Belts.Visualizers.Pulleys.PulleyBoard pulleyShape,
    initialPosition={0.03,-0.05,0},
    animateTorque=false,
    showMarker=true) 
    annotation (extent=[-10,-38; 10,-18], rotation=0);
equation 
  connect(wrapAngleLowerPulley.spanConnector_b, spanLower2Right.spanConnector_a) 
                                                             annotation (points=[4.24264,
        -20; 19.6464,-20; 19.6464,-20.0711; 65.9289,-20.0711],         style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(wrapAngleLeftPulley.spanConnector_b, spanLeft2Lower.spanConnector_a) 
                                                            annotation (points=[-80,
        5.75736; -80,-5.92893; -80.0711,-5.92893],                   style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(spanLeft2Lower.spanConnector_b, wrapAngleLowerPulley.spanConnector_a) 
                                                             annotation (points=[-65.9289,
        -20.0711; -34.9644,-20.0711; -34.9644,-20; -4.24264,-20],
      style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(spanUpper2Left.spanConnector_a, wrapAngleUpperPulley.spanConnector_b) 
                                                            annotation (points=[-65.9289,
        40.0711; -34.9644,40.0711; -34.9644,40; -4.24264,40],           style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(spanUpper2Left.spanConnector_b, wrapAngleLeftPulley.spanConnector_a) 
                                                           annotation (points=[-80.0711,
        25.9289; -80.0711,19.9644; -80,19.9644; -80,14.2426],          style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(spanLower2Right.spanConnector_b, wrapAngleRightPulley.spanConnector_a) 
                                                             annotation (points=[80.0711,
        -5.92893; 80.0711,-0.964465; 80,-0.964465; 80,5.75736],         style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(wrapAngleRightPulley.spanConnector_b, spanRight2Upper.spanConnector_a) 
                                                             annotation (points=[80,
        14.2426; 80,25.9289; 80.0711,25.9289],                style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(LeftPulley.wrapAngleConnector_a, wrapAngleLeftPulley.wrapAngleConnector_b) 
    annotation (points=[-74.2,16.2; -78,14.2; -78,9.85858; -81.5556,9.85858],
      style(
      color=0,
      rgbcolor={50,50,50},
      pattern=3,
      thickness=2));
  connect(RightPulley.wrapAngleConnector_a, wrapAngleRightPulley.wrapAngleConnector_b) 
    annotation (points=[74.2,16.2; 78,14.2; 78,10; 80,10; 80,10.1414; 81.5556,
        10.1414],
      style(
      color=0,
      rgbcolor={50,50,50},
      pattern=3,
      thickness=2));
  
  connect(spanRight2Upper.spanConnector_b, wrapAngleUpperPulley.spanConnector_a) 
    annotation (points=[65.9289,40.0711; 34.9644,40.0711; 34.9644,40; 4.24264,
        40], style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(upperPulley.wrapAngleConnector_a, wrapAngleUpperPulley.wrapAngleConnector_b) 
    annotation (points=[4.2,47.8; -0.141421,45.8; -0.141421,38.4444], style(
      color=0,
      rgbcolor={50,50,50},
      pattern=3,
      thickness=2));
  connect(upperPulley.frame_b, spring.frame_b) annotation (points=[9.79685e-016,
        60; -30,60; -30,20], style(
      color=10,
      rgbcolor={95,95,95},
      thickness=2));
  connect(lowerPulley.wrapAngleConnector_a, wrapAngleLowerPulley.wrapAngleConnector_b) 
    annotation (points=[-4.2,-23.8; 0.141421,-25.8; 0.141421,-18.4444], style(
      color=0,
      rgbcolor={50,50,50},
      pattern=3,
      thickness=2));
  connect(lowerPulley.frame_b, spring.frame_a) annotation (points=[0,-36; -30,
        -36; -30,0], style(
      color=10,
      rgbcolor={95,95,95},
      thickness=2));
end FloatingPulleys;
