model MultiBelt "Belt drive with two connected belt layers" 
  
  annotation (Documentation(info="<HTML>
<p>
 Advanced example for the use of belts and pulleys on different layers. In the drive there are two different belts, which are connected by 
 the pulleys AC_1 and AC_2. <br>
 For simulation you can either select the simulation button <IMG SRC=\"../Pics/simulation.PNG\"> or <b>Commands</b> and <b>span forces in 
 the belt in [N]</b>. <br>
 After the simulation of the model, it's possible to display the rotational angles, rotational velocities and the span forces automatically 
 by selecting <b>Commands</b> and <b>span forces in the belt in [N]</b>, and so on. For an appropriate animation speed select 
 <b>Speed: 0.1</b> in the animation speed pull down menu of the <b>Simulation tab</b>. 
</p>
<p>
  <IMG SRC=\"../Pics/MultiBeltExample.PNG\"
</p>
</HTML>
"), Diagram,
    Commands(
      executeCall(ensureSimulated=true) = plot({"span_AC1_KW.SpanForce",
        "span_KW_AC1.SpanForce","span_AC2_KW.SpanForce",
        "span_ALT_AC2.SpanForce"}) "span forces in the belts in [N]",
      executeCall(ensureSimulated=true) = plot({"ALT.pulleyInertia.phi",
        "AC_2.pulleyInertia.phi","CR.pulleyInertia.phi",
        "AC_1.pulleyInertia.phi"}) "rotational angle of the pulleys in [rad]",
      executeCall(ensureSimulated=true) = plot({"ALT.pulleyInertia.w",
        "AC_2.pulleyInertia.w","CR.pulleyInertia.w","AC_1.pulleyInertia.w"}) 
        "rotational velocity of the pulleys in  [rad/s]"),
    experiment,
    experimentSetupOutput);
  extends Modelica.Icons.Example;
  inner Modelica.Mechanics.MultiBody.World world(g=0, enableAnimation=true,
    animateWorld=false,
    animateGravity=false) 
    annotation (extent=[-94,86; -84,96]);
  ModelElements.FixedPulley ALT(
    diameter=0.059,
    animateHubloads=false,
    animateTorque=false,
    position={0.1814,0.1189},
    redeclare Belts.Visualizers.Pulleys.PulleyHub pulleyShape,
    inertia=1.7e-3,
    showMarker=true) "alternator" 
    annotation (extent=[-80,-50; -60,-30]);
  ModelElements.FixedPulley AC_2(
    diameter=0.123,
    inertia=2.3e-3,
    animateHubloads=false,
    animateTorque=false,
    position={0.123,-0.1606},
    redeclare model ContactModel = Belts.ContactModels.FlatBelt,
    redeclare Belts.Visualizers.Pulleys.PulleyHub pulleyShape,
    showMarker=true) 
    annotation (extent=[40,-60; 60,-40], rotation=180);
  ModelElements.FixedPulley CR(
    diameter=0.153,
    inertia=Belts.Defaults.Inertia,
    animateHubloads=false,
    animateTorque=false,
    redeclare Belts.Visualizers.Pulleys.PulleyHub pulleyShape,
    showMarker=true) "crankshaft " 
    annotation (extent=[-80,40; -60,60]);
  ModelElements.FixedPulley AC_1(
    diameter=0.067,
    inertia=0.0535e-3,
    animateHubloads=false,
    animateTorque=false,
    position={0.123,-0.1606},
    redeclare Belts.Visualizers.Pulleys.PulleyHub pulleyShape,
    showMarker=true) 
    annotation (extent=[40,30; 60,50], rotation=180);
  ModelElements.Span span_AC1_KW(                         z=0,
    redeclare Belts.Visualizers.BeltShapes.DPK beltShape,
    modeShapes=3,
    InitialElongation=0,
    animateSpanForces=false) 
    annotation (extent=[-20,50; 0,70],rotation=180);
  ModelElements.Span span_KW_AC1(                         z=0,
    redeclare Belts.Visualizers.BeltShapes.DPK beltShape,
    modeShapes=3,
    InitialElongation=0,
    animateSpanForces=false) 
    annotation (extent=[-20,20; 0,40]);
  ModelElements.Span span_AC2_KW(                         z=0.1,
    redeclare Belts.Visualizers.BeltShapes.RoundEdge beltShape,
    modeShapes=3,
    InitialElongation=0,
    animateSpanForces=false) 
    annotation (extent=[-20,-40; 0,-20],rotation=180);
  ModelElements.Span span_ALT_AC2(                         z=0.1,
    redeclare Belts.Visualizers.BeltShapes.RoundEdge beltShape,
    modeShapes=3,
    InitialElongation=0,
    animateSpanForces=false) 
    annotation (extent=[-20,-70; 0,-50]);
  ModelElements.WrapAngle wrapAngle_KW(z=0, redeclare 
      Belts.Visualizers.BeltShapes.DPK beltShape) 
    annotation (extent=[-87,47; -67,67], rotation=0);
  ModelElements.WrapAngle wrapAngle_ALT(z=0.1, redeclare 
      Belts.Visualizers.BeltShapes.RoundEdge beltShape) 
    annotation (extent=[-87,-43; -67,-23], rotation=0);
  ModelElements.WrapAngle wrapAngle_AC1(z=0, redeclare 
      Belts.Visualizers.BeltShapes.DPK beltShape) 
    annotation (extent=[67,43; 47,23], rotation=0);
  ModelElements.WrapAngle wrapAngle_AC2(z=0.1, redeclare 
      Belts.Visualizers.BeltShapes.RoundEdge beltShape) 
    annotation (extent=[67,-47; 47,-67], rotation=0);
  Modelica.Mechanics.Rotational.Inertia inertia(J=0.005) 
    annotation (extent=[20,-10; 40,10], rotation=90);
  
protected 
  Modelica.Mechanics.MultiBody.Visualizers.Advanced.Shape PullyConnection(
    shapeType="cylinder",
    color={155,155,155},
    r_shape={0,0,0},
    lengthDirection={0,0,1},
    widthDirection={1,0,0},
    length=0.1,
    width=0.028,
    height=0.028,
    r={AC_1.position[1],AC_1.position[2],0});
  
public 
  Modelica.Mechanics.Rotational.Torque torque 
    annotation (extent=[4,74; 24,94], rotation=180);
  Modelica.Blocks.Sources.Constant const(k=2) 
    annotation (extent=[50,74; 70,94], rotation=180);
equation 
  connect(inertia.flange_a, AC_2.flange_b) 
    annotation (points=[30,-10; 30,-50;50,-50],
                style(color=0, rgbcolor={0,0,0}));
  connect(inertia.flange_b, AC_1.flange_b) 
    annotation (points=[30,10; 30,40; 50,40],
                style(color=0, rgbcolor={0,0,0}));
  annotation (Diagram);
  connect(wrapAngle_KW.spanConnector_b, span_KW_AC1.spanConnector_a) 
                                                            annotation (points=[-80,54;
        -80,30; -20,30],          style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(span_AC1_KW.spanConnector_a, wrapAngle_AC1.spanConnector_b) 
                                                            annotation (points=[0,60; 60,
        60; 60,36],            style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(wrapAngle_AC1.spanConnector_a, span_KW_AC1.spanConnector_b) 
                                                             annotation (points=[54,30; 0,
        30],          style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(span_AC2_KW.spanConnector_a, wrapAngle_AC2.spanConnector_b) 
                                                             annotation (points=[0,-30;
        60,-30; 60,-54],         style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(wrapAngle_AC2.spanConnector_a, span_ALT_AC2.spanConnector_b) 
                                                             annotation (points=[54,-60;
        0,-60],         style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(span_ALT_AC2.spanConnector_a, wrapAngle_ALT.spanConnector_b) 
                                                             annotation (points=[-20,-60;
        -80,-60; -80,-36],          style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(wrapAngle_KW.wrapAngleConnector_b,CR. wrapAngleConnector_a) 
                                                                   annotation (
      points=[-78.2,58; -78.2,54.2; -74.2,54.2],         style(
      color=0,
      rgbcolor={50,50,50},
      pattern=3,
      thickness=2));
  connect(AC_1.wrapAngleConnector_a, wrapAngle_AC1.wrapAngleConnector_b) 
    annotation (points=[54.2,35.8; 56.1,35.8; 56.1,32; 58.2,32],   style(
      color=0,
      rgbcolor={50,50,50},
      pattern=3,
      thickness=2));
  connect(AC_2.wrapAngleConnector_a, wrapAngle_AC2.wrapAngleConnector_b) 
    annotation (points=[54.2,-54.2; 56.1,-54.2; 56.1,-58; 58.2,-58],   style(
      color=0,
      rgbcolor={50,50,50},
      pattern=3,
      thickness=2));
  connect(wrapAngle_ALT.wrapAngleConnector_b, ALT.wrapAngleConnector_a) 
    annotation (points=[-78.2,-32; -78.2,-32; -76,-35.8; -74.2,-35.8], style(
      color=0,
      rgbcolor={50,50,50},
      pattern=3,
      thickness=2));
  connect(span_AC1_KW.spanConnector_b, wrapAngle_KW.spanConnector_a) 
    annotation (points=[-20,60; -74,60],
                                       style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(wrapAngle_ALT.spanConnector_a, span_AC2_KW.spanConnector_b) 
    annotation (points=[-74,-30; -20,-30],
                                         style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(CR.flange_b, torque.flange_b) annotation (points=[-70,50; -30,50; -30,
        84; 4,84], style(color=0, rgbcolor={0,0,0}));
  connect(torque.tau, const.y) 
    annotation (points=[26,84; 49,84], style(color=74, rgbcolor={0,0,127}));
end MultiBelt;
