model PassengerCarAccessoryDrive 
  "Passenger car accessory drive with flanged engine" 
  
  annotation (Documentation(info="<HTML>
<p>
 This is an example for a passenger car accessory drive with a flanged motor. In the animation the crankshaft, the rod, the piston and the 
 accessory drive are visible. The belt is tensioned by a hydraulic tensioner, which is connected with a linear spring/damper combination. <br>
 For simulation you can either select the simulation button <IMG SRC=\"../Pics/simulation.PNG\"> or <b>Commands</b> and <b>span forces in 
 the belt in [N]</b>. <br>
 After the simulation of the model, it's possible to display the rotational velocities (of selected pulleys) automatically by selecting <b>Commands </b> 
 and <b>rotational velocity of the pulleys in [rad/s]</b>. For an appropriate animation speed select <b>Speed: 0.1</b> in the animation speed pull 
 down menu of the <b>Simulation tab</b>. 
</p>
<p>
  <IMG SRC=\"../Pics/PassengerCarAccessoryDriveWithEngine.PNG\"
</p>
<p>
 The slippage between the belt and the different pulleys can be seen by regarding the increasing relative angle between the outer red and 
 the inner black markers. In the illustration below such a difference between the two markers, caused by slippage, is visible.
</p>
<p>
  <IMG SRC=\"../Pics/slippage.PNG\"
</p>
</HTML>
"), Diagram,
    Commands(executeCall(ensureSimulated=true) = plot({"speedSensor_KW.w",
        "speedSensor_HP.w","speedSensor_KL.w","speedSensor_U3.w",
        "speedSensor_SG.w"}) "rotational velocity of pulleys in [rad/s]"),
    experiment(StopTime=0.5),
    experimentSetupOutput(StoreProtectedVariables=true));
  
  extends Modelica.Icons.Example;
  annotation (experiment(StopTime=0.5),uses(Modelica(version="2.2.2"), Belts(version="2.0")), Diagram,
    Commands(executeCall(ensureSimulated=true) = plot({"load.w"}) 
        "rotational velocity in rad/s"));
  inner Modelica.Mechanics.MultiBody.World world(animateGravity=false,
      animateWorld=false,
    enableAnimation=true) 
                         annotation (extent=[-74,65; -58,81]);
  Modelica.Mechanics.MultiBody.Joints.ActuatedRevolute actuatedRevolute(
    n={0,0,1},
    planarCutJoint=false,
    animation=false) 
    annotation (extent=[-32,28; -52,48], rotation=180);
  Modelica.Mechanics.Rotational.Inertia load(
                          phi(
      start=0,
      fixed=true,
      stateSelect=StateSelect.always),
    J=1,
    w(start=10,
      fixed=true,
      stateSelect=StateSelect.always)) annotation (extent=[37,28; 52,46]);
  Modelica.Mechanics.Rotational.QuadraticSpeedDependentTorque 
    quadraticSpeedDependentTorque(tau_nominal=-100, w_nominal=20) 
    annotation (extent=[80,29; 65,45],   rotation=0);
  cylinder_modified cylinder_modified1(
    crankAngleOffset=45,
    pistonLength=0.1,
    cylinderTopPosition=0.42)             annotation (extent=[-24,58; -2,80]);
  
protected 
          model cylinder_modified 
    
    annotation (
      uses(Modelica(version="2.2.2")), 
      Coordsys(extent=[-150,-150; 150,
          150], scale=0.1), 
      Diagram, 
      Icon(
        Polygon(points=[-49,-72; -49,78; 71,78; 71,-74; 111,-74; 111,128; -89,
              128; 
            -89,-72; -49,-72],                    style(color=0, fillColor=8)), 
        Rectangle(extent=[-47,67; 69,-9], style(gradient=1, fillColor=8)), 
        Rectangle(extent=[-49,59; 71,53], style(color=0, fillColor=0)), 
        Rectangle(extent=[-49,45; 71,39], style(color=0, fillColor=0)), 
        Rectangle(extent=[-49,33; 71,27], style(color=0, fillColor=0)), 
        Polygon(points=[-49,-11; -31,1; 49,1; 67,-11; -49,-11], style(
            pattern=0, fillColor=7)), 
        Ellipse(extent=[5,19; 13,11], style(color=0, fillColor=0)), 
        Ellipse(extent=[-29,-151; 51,-71], style(color=8)), 
        Line(points=[11,-112; 37,-80; 9,15], style(color=0, thickness=4)), 
        Text(extent=[-139,-146; 175,-208], string="%name"), 
        Line(points=[-89,-112; 111,-113], style(color=0, thickness=2))));
    
    import SI = Modelica.SIunits;
    parameter Boolean animation=true "= true, if animation shall be enabled";
    parameter SI.Length cylinderTopPosition=0.42 
      "Length from crank shaft to end of cylinder.";
    parameter SI.Length pistonLength=0.1 "Length of cylinder";
    parameter SI.Length rodLength=0.2 "Length of rod";
    parameter SI.Length crankLength=0.2 "Length of crank shaft in z direction";
    parameter SI.Length crankPinOffset=0.1 
      "Offset of crank pin from center axis";
    parameter SI.Length crankPinLength=0.1 
      "Offset of crank pin from center axis";
    parameter SI.Angle cylinderInclination=0 "Inclination of cylinder";
    parameter SI.Angle crankAngleOffset=0 "Offset for crank angle";
    parameter SI.Length cylinderLength=cylinderTopPosition - 
                                                           (pistonLength +rodLength -
        crankPinOffset) "Maximum length of cylinder volume";
    
    Modelica.Mechanics.MultiBody.Parts.BodyCylinder Crank3(diameter=0.03, r={0,
          0,0.1})                                                                    annotation (
      extent=[7.5,-81; 27.5,-61], 
      rotation=0, 
      style(color=0, thickness=2));
    Modelica.Mechanics.MultiBody.Parts.FixedTranslation Mid(r={0,0,0.05})
      annotation (extent=[10,-63; 30,-43]);
    Modelica.Mechanics.MultiBody.Parts.FixedTranslation fixedTranslation1(animation=false, r={0,0,
          crankLength}) annotation (extent=[-54.5,96; -34.5,116]);
    Modelica.Mechanics.MultiBody.Parts.BodyCylinder Crank1(r={0,0,0.1}, 
        diameter=0.05) annotation (extent=[-39,-122; -19,-102], rotation=0);
    Modelica.Mechanics.MultiBody.Parts.BodyBox Crank2(
      r={0,0.1,0}, 
      widthDirection={1,0,0}, 
      width=0.02, 
      height=0.03) 
                annotation (extent=[-12,-103; 8,-83],  rotation=90);
    Modelica.Mechanics.MultiBody.Parts.BodyBox Crank4(
      widthDirection={1,0,0}, 
      width=0.02, 
      r={0,-0.1,0}, 
      height=0.03) 
                  annotation (extent=[31.5,-83; 51.5,-103],    rotation=90);
    Modelica.Mechanics.MultiBody.Interfaces.Frame_a frame_a
      annotation (extent=[-106,90; -74,122]);
    Modelica.Mechanics.MultiBody.Interfaces.Frame_a frame_a1
      annotation (extent=[-110,-128; -78,-96]);
    Modelica.Mechanics.MultiBody.Interfaces.Frame_a frame_a2
      annotation (extent=[95,90; 127,122]);
    Modelica.Mechanics.MultiBody.Interfaces.Frame_a frame_a3
      annotation (extent=[95,-128; 127,-96]);
    Modelica.Mechanics.MultiBody.Parts.FixedRotation fixedRotation(
      r={0,0,crankLength - crankPinLength/2}, 
      animation=false, 
      n_x={0,0,1}, 
      n_y={0,cos(cylinderInclination),sin(cylinderInclination)}, 
      rotationType=Modelica.Mechanics.MultiBody.Types.RotationTypes.RotationAxis, 
      n={0,0,1}, 
      angle=cylinderInclination) 
                               annotation (extent=[-70,28; -50,48]);
    
    Modelica.Mechanics.MultiBody.Parts.FixedTranslation fixedTranslation(r={0,
          cylinderTopPosition,0}, animation=false)
      annotation (extent=[-50,52; -30,72], rotation=90);
    Modelica.Mechanics.MultiBody.Parts.FixedRotation fixedRotation1(
      animation=false, 
      n_x={0,0,1}, 
      n_y={0,cos(crankAngleOffset),sin(crankAngleOffset)}, 
      rotationType=Modelica.Mechanics.MultiBody.Types.RotationTypes.RotationAxis, 
        
      n={0,0,1}, 
      angle=crankAngleOffset) 
                            annotation (extent=[-73,-122; -53,-102]);
    
    Modelica.Mechanics.MultiBody.Parts.FixedRotation fixedRotation2(
      animation=false, 
      n_x={0,0,1}, 
      n_y={0,cos(-crankAngleOffset),sin(-crankAngleOffset)}, 
      rotationType=Modelica.Mechanics.MultiBody.Types.RotationTypes.RotationAxis, 
        
      n={0,0,1}, 
      angle=-crankAngleOffset) 
                             annotation (extent=[62,-122; 82,-102]);
    
    Modelica.Mechanics.MultiBody.Joints.Assemblies.JointRRP jointRRP(
      n_b={0,-1,0}, 
      animation=false, 
      rRod1_ia={0,0.2,0}, 
      rRod2_ib={0,-0.1,0}, 
      n_a={0,0,1}) annotation (extent=[36,-2; -4,38], rotation=90);
    Modelica.Mechanics.MultiBody.Parts.BodyCylinder Piston(diameter=0.1, r={0,-0.1,
          0}) annotation (extent=[127,10; 67,30], rotation=270);
    Modelica.Mechanics.MultiBody.Parts.BodyBox Rod2(
      widthDirection={1,0,0}, 
      width=0.02, 
      height=0.06, 
      color={0,0,200}, 
      r={0,0.2,0})   annotation (extent=[88,-21; 108,-1],  rotation=270);
    gasForce_modified myGasForce1(
                         L=cylinderLength, d=0.1)
      annotation (extent=[34,55; 54,75], rotation=90);
            model gasForce_modified 
      import SI = Modelica.SIunits;
      
              extends Modelica.Mechanics.Translational.Interfaces.Compliant;
              parameter SI.Length L "Length of cylinder";
              parameter SI.Length d "diameter of cylinder";
              parameter Real k0=0.01;
              parameter Real k1=1;
              parameter Real k=1;
              constant Real pi=Modelica.Constants.pi;
              constant Real PI=Modelica.Constants.pi;
              // Only for compatibility reasons
              Real x "Normalized position of cylinder";
              Real y "Normalized relative movement (= -s_rel/L)";
              SI.Density dens;
              Modelica.SIunits.Conversions.NonSIunits.Pressure_bar press 
        "cylinder pressure";
              SI.Volume V;
              SI.Temperature T;
              SI.Velocity v_rel;
              annotation (Icon(
                  Rectangle(extent=[-90, 50; 90, -50], style(
                      color=0,
                      gradient=0,
                      fillColor=8,
                      fillPattern=1)),
                  Rectangle(extent=[-40, 50; -20, -50], style(fillColor=3,
                        fillPattern =                                                  1)),
                  Rectangle(extent=[-90, 10; -40, -10], style(fillColor=3,
                        fillPattern =                                                  1)),
                  Polygon(points=[60, 2; 54, 2; 0, 2; 0, 10; -20, 0; 0, -10; 0, -4; 60, -4;
                         60, 2], style(
                      color=1,
                      fillColor=1,
                      fillPattern=1)),
                  Text(extent=[-100, 120; 100, 60], string="%name")), Diagram(
                  Rectangle(extent=[-90, 50; 90, -50], style(
                      color=0,
                      gradient=0,
                      fillColor=8,
                      fillPattern=1)),
                  Rectangle(extent=[-40, 50; -20, -50], style(fillColor=3,
                        fillPattern =                                                  1)),
                  Rectangle(extent=[-90, 10; -40, -10], style(fillColor=3,
                        fillPattern =                                                  1)),
                  Polygon(points=[60, 2; 54, 2; 0, 2; 0, 10; -20, 0; 0, -10; 0, -4; 60, -4;
                         60, 2], style(
                      color=1,
                      fillColor=1,
                      fillPattern=1)),
                  Text(extent=[-100, 120; 100, 60], string="%name")),
                uses(Modelica(version="2.2.2")));
      
            equation 
              y = -s_rel/L;
              x = 1 + s_rel/L;
              v_rel = der(s_rel);
      
              // model of the motor
              press = if v_rel < 0 then (if x < 0.987 then 177.4132*x^4 - 287.2189*x^3 +
                151.8252*x^2 - 24.9973*x + 2.4 else 2836360*x^4 - 10569296*x^3 + 14761814
                *x^2 - 9158505*x + 2129670) else (if x > 0.93 then -3929704*x^4 +
                14748765*x^3 - 20747000*x^2 + 12964477*x - 3036495 else 145.930*x^4 -
                131.707*x^3 + 17.3438*x^2 + 17.9272*x + 2.4);
      
              f = -1.0E5*press*pi*d^2/4;
      
              V = k0 + k1*(1 - x);
              dens = 1/V;
              // ideal gas
              press*V = k*T;
            end gasForce_modified;
    
          equation 
    connect(Mid.frame_a, Crank2.frame_b) annotation (points=[10,-53; -2,-53; -2,
          -83], style(
        color=10, 
        rgbcolor={95,95,95}, 
        thickness=2));
    connect(Crank2.frame_b, Crank3.frame_a) annotation (points=[-2,-83; -2,-71; 
          7.5,-71], style(
        color=10, 
        rgbcolor={95,95,95}, 
        thickness=2));
    connect(frame_a, fixedTranslation1.frame_a) annotation (points=[-90,106; -54.5,
          106], style(
        color=10, 
        rgbcolor={95,95,95}, 
        thickness=2));
    connect(Crank1.frame_b, Crank2.frame_a) annotation (points=[-19,-112; -2,
          -112; -2,-103],
                    style(
        color=10, 
        rgbcolor={95,95,95}, 
        thickness=2));
    connect(Crank3.frame_b, Crank4.frame_a) annotation (points=[27.5,-71; 42,-71; 
          42,-83; 41.5,-83], style(
        color=10, 
        rgbcolor={95,95,95}, 
        thickness=2));
    connect(fixedTranslation1.frame_b, frame_a2) annotation (points=[-34.5,106; 
          111,106], style(
        color=10, 
        rgbcolor={95,95,95}, 
        thickness=2));
    connect(frame_a, fixedRotation.frame_a) annotation (points=[-90,106; -82,
          106; -82,38; -70,38], style(
        color=10, 
        rgbcolor={95,95,95}, 
        thickness=2));
    connect(fixedRotation.frame_b, fixedTranslation.frame_a) annotation (points
        =[-50,38; -40,38; -40,52], style(
        color=10, 
        rgbcolor={95,95,95}, 
        thickness=2));
    connect(frame_a1, fixedRotation1.frame_a) annotation (points=[-94,-112; -73,
          -112], style(
        color=10, 
        rgbcolor={95,95,95}, 
        thickness=2));
    connect(fixedRotation1.frame_b, Crank1.frame_a) annotation (points=[-53,-112; 
          -39,-112], style(
        color=10, 
        rgbcolor={95,95,95}, 
        thickness=2));
    connect(Crank4.frame_b, fixedRotation2.frame_a) annotation (points=[41.5,-103; 
          41.5,-112; 62,-112], style(
        color=10, 
        rgbcolor={95,95,95}, 
        thickness=2));
    connect(fixedRotation2.frame_b, frame_a3) annotation (points=[82,-112; 111,
          -112], style(
        color=10, 
        rgbcolor={95,95,95}, 
        thickness=2));
    connect(frame_a2, frame_a2) annotation (points=[111,106; 112,106; 112,106; 
          111,106], style(
        color=10, 
        rgbcolor={95,95,95}, 
        thickness=2));
    connect(jointRRP.frame_a, Mid.frame_b) annotation (points=[16,-2; 16,-40; 
          42,-40; 42,-53; 30,-53], style(
        color=10, 
        rgbcolor={95,95,95}, 
        thickness=2));
    connect(fixedTranslation.frame_b, jointRRP.frame_b) annotation (points=[-40,
          72; -40,82; 16,82; 16,38], style(
        color=10, 
        rgbcolor={95,95,95}, 
        thickness=2));
    connect(jointRRP.frame_ib, Piston.frame_a) annotation (points=[36,34; 97,34; 
          97,30], style(
        color=10, 
        rgbcolor={95,95,95}, 
        thickness=2));
    connect(jointRRP.frame_ia, Rod2.frame_a) annotation (points=[36,2; 98,2; 98,
          -1], style(
        color=10, 
        rgbcolor={95,95,95}, 
        thickness=2));
    connect(jointRRP.bearing, myGasForce1.flange_b) annotation (points=[24,38; 
          24,80; 44,80; 44,75], style(color=58, rgbcolor={0,127,0}));
    connect(myGasForce1.flange_a, jointRRP.axis) annotation (points=[44,55; 44,
          50; 32,50; 32,38], style(color=58, rgbcolor={0,127,0}));
          end cylinder_modified;
  
protected 
  cylinder_modified cylinder_modified2(
    crankAngleOffset=225,
    pistonLength=0.1,
    cylinderTopPosition=0.42)              annotation (extent=[2,58; 24,80]);
  cylinder_modified cylinder_modified3(
    crankAngleOffset=225,
    pistonLength=0.1,
    cylinderTopPosition=0.42)              annotation (extent=[28,58; 50,80]);
  cylinder_modified cylinder_modified4(
    crankAngleOffset=45,
    pistonLength=0.1,
    cylinderTopPosition=0.42)              annotation (extent=[54,58; 76,80]);
  Layout AccessoryDrive(
    animate=true,
    MShapes=0,
    redeclare model ContactModel = Belts.ContactModels.VBelt) 
    annotation (extent=[-28,-16; 34,40]);
  
model Layout 
annotation (Commands(
executeCall(ensureSimulated=true) = plot({
"PS_CR.SpanForce",
"CR_AC.SpanForce",
"AC_WP.SpanForce",
"WP_AL.SpanForce",
"AL_IP.SpanForce",
"IP_TP.SpanForce",
"TP_PS.SpanForce"}) " span force in the belt in [N]",
executeCall(ensureSimulated=true) = plot({
"PS.pulleyInertia.phi",
"CR.pulleyInertia.phi",
"AC.pulleyInertia.phi",
"WP.pulleyInertia.phi",
"AL.pulleyInertia.phi",
"IP.pulleyInertia.phi",
"TP.pulleyInertia.phi"}) " rotational angles of the pulleys in [rad]",
executeCall(ensureSimulated=true) = plot({
"PS.pulleyInertia.w",
"CR.pulleyInertia.w",
"AC.pulleyInertia.w",
"WP.pulleyInertia.w",
"AL.pulleyInertia.w",
"IP.pulleyInertia.w",
"TP.pulleyInertia.w"}) " rotational velocities of the pulleys in [rad/s]"),
        Diagram);
    
replaceable model ContactModel = Belts.ContactModels.FlatBelt extends 
      Belts.Interfaces.PartialContactModel 
      "Contact model for pulley-belt contact" 
  annotation (choicesAllMatching= true, Diagram);
    
parameter Real d(
 final unit= "N.s/m",
 final min=0) = 100 "Damping constant" 
 annotation(Dialog(group="Spring/Damper parameters"));
parameter Real EA(
 final unit="N",
 final min=0) = 160000 "longitudinal belt stiffness" 
 annotation(Dialog(group="Belt parameters"));
parameter Real mr(
 final unit="kg/m",
 final min=0) = Belts.Defaults.mr "belt mass per meter" 
 annotation(Dialog(group="Belt parameters"));
parameter Real F0(
 final unit="N",
 final min=0) = 710.435 "preload" 
 annotation(Dialog(group="Belt parameters"));
parameter Boolean animate=false 
      "=true, if animation of all components is enabled" 
 annotation(Dialog(group="Animation"));
parameter Real CRstart(
 final unit="rad/s",
 final min=0) = 0 "Initial value angular velocity of the crankshaft" 
 annotation(Dialog(group="Rotational velocity"));
parameter Integer MShapes=3 "number of mode shapes for transversal vibration" 
 annotation(Dialog(group="Animation"));
    
// Description of the different pulleys
Belts.ModelElements.FixedPulley PS(
 diameter=0.1,
 position={0.11,0.08},
 animateHubloads=false,
 animateTorque=false,
 inside=false,
 w_start=CRstart*1.428*(-1),
redeclare model ContactModel = ContactModel,
    redeclare Belts.Visualizers.Pulleys.PulleyHub pulleyShape,
    showMarker=true) "power steering pulley" 
 annotation (extent=[90,61; 130,99],  rotation=0);
Belts.ModelElements.FixedPulley CR(
 diameter=0.14,
 position={0,0},
 animateHubloads=false,
 animateTorque=false,
 inside=true,
 w_start=CRstart,
redeclare model ContactModel = ContactModel,
    redeclare Belts.Visualizers.Pulleys.PulleyHub pulleyShape,
    showMarker=true) "crankshaft pulley" 
 annotation (extent=[-20,-19; 20,19], rotation=0);
Belts.ModelElements.FixedPulley AC(
 diameter=0.115,
 position={0.185,-0.12},
 animateHubloads=false,
 animateTorque=false,
 inside=true,
 w_start=CRstart*1.24174*1,
redeclare model ContactModel = ContactModel,
    redeclare Belts.Visualizers.Pulleys.PulleyHub pulleyShape,
    showMarker=true) "air condition pulley" 
 annotation (extent=[162.6,-139.2; 201,-101],     rotation=0);
Belts.ModelElements.FixedPulley WP(
 position={0.295,-0.05},
 animateHubloads=false,
 animateTorque=false,
 inside=false,
 w_start=CRstart*1.29818*(-1),
redeclare model ContactModel = ContactModel,
    redeclare Belts.Visualizers.Pulleys.PulleyHub pulleyShape,
    showMarker=true,
      diameter=0.08) "water pump pulley" 
 annotation (extent=[264,-54; 297.5,-18.7],     rotation=0);
Belts.ModelElements.FixedPulley AL(
 diameter=0.065,
 position={0.36,0.04},
 animateHubloads=false,
 animateTorque=false,
 inside=true,
 w_start=CRstart*2.19692*1,
redeclare model ContactModel = ContactModel,
    redeclare Belts.Visualizers.Pulleys.PulleyHub pulleyShape,
    showMarker=true) "alternator pulley" 
 annotation (extent=[342,23; 377,57], rotation=0);
Belts.ModelElements.FixedPulley IP(
 diameter=0.075,
 position={0.225,0.035},
 animateHubloads=false,
 animateTorque=false,
 inside=false,
 w_start=CRstart*1.904*(-1),
redeclare model ContactModel = ContactModel,
    redeclare Belts.Visualizers.Pulleys.PulleyHub pulleyShape,
    showMarker=true) "idler pulley" 
 annotation (extent=[208.7,17.2; 243,51],     rotation=0);
Belts.ModelElements.FreePulley TP(
 diameter=0.05,
 animateHubloads=false,
 animateTorque=false,
 inside=true,
 w_start=CRstart*2.856*1,
redeclare model ContactModel = ContactModel,
    redeclare Belts.Visualizers.Pulleys.PulleyHub pulleyShape,
    showMarker=true) "tensioner pulley" 
 annotation (extent=[262.193,95.308; 294,129],          rotation=0);
    
// Description of the wrap angles and the spans
Belts.ModelElements.WrapAngle wrapAngle_PS(redeclare 
        Belts.Visualizers.BeltShapes.VBelt beltShape) 
annotation (extent=[80,69; 124,111]);
Belts.ModelElements.Span PS_CR(animateSpanForces=false,
EA=EA,
F0=F0,
mr=mr,
modeShapes=MShapes,
    redeclare Belts.Visualizers.BeltShapes.VBelt beltShape) 
annotation (extent=[-6,66; 14,86], rotation=-135);
Belts.ModelElements.WrapAngle wrapAngle_CR(redeclare 
        Belts.Visualizers.BeltShapes.VBelt beltShape) 
annotation (extent=[-34,-4; 14,38]);
Belts.ModelElements.Span CR_AC(animateSpanForces=false,
EA=EA,
F0=F0,
mr=mr,
modeShapes=MShapes,
    redeclare Belts.Visualizers.BeltShapes.VBelt beltShape) 
annotation (extent=[161.6,-56; 181.6,-36],
                                         rotation=-45);
Belts.ModelElements.WrapAngle wrapAngle_AC(redeclare 
        Belts.Visualizers.BeltShapes.VBelt beltShape) 
annotation (extent=[145.6,-132.2; 196,-86]);
Belts.ModelElements.Span AC_WP(animateSpanForces=false,
EA=EA,
F0=F0,
mr=mr,
modeShapes=MShapes,
    redeclare Belts.Visualizers.BeltShapes.VBelt beltShape) 
annotation (extent=[239.5,-150.2; 259.5,-130.2], rotation=45);
Belts.ModelElements.WrapAngle wrapAngle_WP(redeclare 
        Belts.Visualizers.BeltShapes.VBelt beltShape) 
annotation (extent=[318.5,-50.7; 256,-1]);
Belts.ModelElements.Span WP_AL(animateSpanForces=false,
EA=EA,
F0=F0,
mr=mr,
modeShapes=MShapes,
    redeclare Belts.Visualizers.BeltShapes.VBelt beltShape) 
annotation (extent=[376,-49.7; 396,-29.7], rotation=45);
Belts.ModelElements.WrapAngle wrapAngle_AL(redeclare 
        Belts.Visualizers.BeltShapes.VBelt beltShape) 
annotation (extent=[328,30; 378,70]);
Belts.ModelElements.Span AL_IP(animateSpanForces=false,
EA=EA,
F0=F0,
mr=mr,
modeShapes=MShapes,
    redeclare Belts.Visualizers.BeltShapes.VBelt beltShape) 
annotation (extent=[263.7,40; 283.7,60], rotation=180);
Belts.ModelElements.WrapAngle wrapAngle_IP(redeclare 
        Belts.Visualizers.BeltShapes.VBelt beltShape) 
annotation (extent=[195.7,22.2; 234,64]);
Belts.ModelElements.Span IP_TP(animateSpanForces=false,
EA=EA,
F0=F0,
mr=mr,
modeShapes=MShapes,
    redeclare Belts.Visualizers.BeltShapes.VBelt beltShape) 
annotation (extent=[258.193,56.2; 278.193,76.2], rotation=0);
Belts.ModelElements.WrapAngle wrapAngle_TP(redeclare 
        Belts.Visualizers.BeltShapes.VBelt beltShape) 
annotation (extent=[248.193,101.308; 294,141]);
Belts.ModelElements.Span TP_PS(animateSpanForces=false,
EA=EA,
F0=F0,
mr=mr,
modeShapes=MShapes,
    redeclare Belts.Visualizers.BeltShapes.VBelt beltShape) 
annotation (extent=[131,105.308; 151,125.308], rotation=180);
    
// Description of the lever(s)
Belts.ModelElements.DoubleLever doubleLeverTP(
 pulleyLever={0.1,0,0},
 nominalAngle=-62.4886,
 tensionerAngle=-20.3,
 tensionerLever={0.18,0,0},
    pivotPoint={0.232,0.201,0.05},
    mountingPoint={0.186,-0.017,0.05}) 
 annotation (extent=[328.193,78.3081; 364,115]);
    
// Description of the spring(s) and damper(s)
Modelica.Mechanics.MultiBody.Forces.SpringDamperParallel springDamperParallelTP(
 d=d,
 s_unstretched=0.0981818,
 c=44000,
      width=world.defaultForceWidth/2) 
 annotation (extent=[392.193,79.8081; 422,116],         rotation=270);
    
// Flanges at the center of the different Pulleys
Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_TP 
annotation (extent=[274.193,108.308; 282.193,116.308]);
Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_IP 
annotation (extent=[221.7,30.2; 229.7,38.2]);
Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_AL 
annotation (extent=[356,36; 364,44]);
Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_WP 
annotation (extent=[276.5,-40.7; 284.5,-32.7]);
Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_AC 
annotation (extent=[177.6,-124.2; 185.6,-116.2]);
Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_CR 
annotation (extent=[-4,-4; 4,4]);
Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_PS 
annotation (extent=[106,76; 114,84]);
Modelica.Mechanics.Rotational.Interfaces.Flange_b tensionerFlange_TP 
annotation (extent=[229,198; 235,204]);
    
// the coordinate system
annotation (
 Coordsys(extent=[-120,-227.7; 442.5,251], scale=0.115625),
 uses(Belts(version="2.2"), Modelica(version="2.2.2")),
 Diagram);
    
// animation of the world
inner Modelica.Mechanics.MultiBody.World world(animateWorld=false,
animateGravity=false,
enableAnimation=animate) 
annotation (extent=[-70,181; -50,201]);
    
// connectors between the different elements
  Modelica.Mechanics.MultiBody.Parts.FixedTranslation fixedTranslation(r={0,0,
        0.05}) annotation (extent=[305,103; 337,125]);
equation 
 connect(wrapAngle_PS.wrapAngleConnector_b, PS.wrapAngleConnector_a) 
 annotation (points=[99.36,92.1; 101.6,87.98],
 style(
 color=0,
 rgbcolor={50,50,50},
 pattern=3,
 thickness=2));
 connect(PS_CR.spanConnector_b, wrapAngle_CR.spanConnector_a) 
 annotation (points=[-3.07107,68.9289; -2.8,23.3],
 style(
 color=1,
 rgbcolor={255,0,0},
 pattern=3,
 thickness=2));
 connect(wrapAngle_PS.spanConnector_b, PS_CR.spanConnector_a) 
 annotation (points=[95.4,83.7; 11.0711,83.0711],
 style(
 color=1,
 rgbcolor={255,0,0},
 pattern=3,
 thickness=2));
 connect(PS.flange_b, flange_PS) 
 annotation (points=[110,80; 110,80],
 style(
 color=0,
 rgbcolor={0,0,0}));
 connect(wrapAngle_CR.wrapAngleConnector_b, CR.wrapAngleConnector_a) 
 annotation (points=[-12.88,19.1; -8.4,7.98],
 style(
 color=0,
 rgbcolor={50,50,50},
 pattern=3,
 thickness=2));
 connect(CR_AC.spanConnector_b, wrapAngle_AC.spanConnector_a) 
 annotation (points=[178.671,-53.0711; 178.36,-102.17],
 style(
 color=1,
 rgbcolor={255,0,0},
 pattern=3,
 thickness=2));
 connect(CR.flange_b, flange_CR) 
 annotation (points=[0,0; 0,0],
 style(
 color=0,
 rgbcolor={0,0,0}));
 connect(wrapAngle_AC.wrapAngleConnector_b, AC.wrapAngleConnector_a) 
 annotation (points=[167.776,-106.79; 173.736,-112.078],
 style(
 color=0,
 rgbcolor={50,50,50},
 pattern=3,
 thickness=2));
 connect(AC.flange_b, flange_AC) 
 annotation (points=[181.8,-120.1; 182,-122; 181.6,-120.2],
 style(
 color=0,
 rgbcolor={0,0,0}));
 connect(wrapAngle_WP.wrapAngleConnector_b, WP.wrapAngleConnector_a) 
 annotation (points=[291,-23.365; 273.715,-28.937],
 style(
 color=0,
 rgbcolor={50,50,50},
 pattern=3,
 thickness=2));
 connect(WP.flange_b, flange_WP) 
 annotation (points=[280.75,-36.35; 280,-36; 280.5,-36.7],
 style(
 color=0,
 rgbcolor={0,0,0}));
 connect(wrapAngle_AL.wrapAngleConnector_b, AL.wrapAngleConnector_a) 
 annotation (points=[350,52; 352.15,47.14],
 style(
 color=0,
 rgbcolor={50,50,50},
 pattern=3,
 thickness=2));
 connect(AL_IP.spanConnector_b, wrapAngle_IP.spanConnector_a) 
 annotation (points=[263.7,50; 220.595,49.37],
 style(
 color=1,
 rgbcolor={255,0,0},
 pattern=3,
 thickness=2));
 connect(wrapAngle_AL.spanConnector_b, AL_IP.spanConnector_a) 
 annotation (points=[345.5,44; 310,44; 310,50; 283.7,50],
 style(
 color=1,
 rgbcolor={255,0,0},
 pattern=3,
 thickness=2));
 connect(AL.flange_b, flange_AL) 
 annotation (points=[359.5,40; 360,40],
 style(
 color=0,
 rgbcolor={0,0,0}));
 connect(wrapAngle_IP.wrapAngleConnector_b,IP. wrapAngleConnector_a) 
 annotation (points=[212.552,45.19; 218.647,41.198],
 style(
 color=0,
 rgbcolor={50,50,50},
 pattern=3,
 thickness=2));
 connect(IP_TP.spanConnector_b, wrapAngle_TP.spanConnector_a) 
 annotation (points=[278.193,66.2; 277.968,127.108],
 style(
 color=1,
 rgbcolor={255,0,0},
 pattern=3,
 thickness=2));
 connect(IP.flange_b, flange_IP) 
 annotation (points=[225.85,34.1; 226,34; 225.7,34.2],
 style(
 color=0,
 rgbcolor={0,0,0}));
 connect(wrapAngle_TP.wrapAngleConnector_b, TP.wrapAngleConnector_a) 
 annotation (points=[268.348,123.139; 271.417,119.229],
 style(
 color=0,
 rgbcolor={50,50,50},
 pattern=3,
 thickness=2));
 connect(wrapAngle_TP.spanConnector_b, TP_PS.spanConnector_a) 
 annotation (points=[264.225,115.2; 202.596,115.2; 202.596,115.308; 151,115.308],
 style(
 color=1,
 rgbcolor={255,0,0},
 pattern=3,
 thickness=2));
 connect(TP.flange_b, flange_TP) 
 annotation (points=[278.096,112.154; 278,112; 278.193,112.308],
 style(
 color=0,
 rgbcolor={0,0,0}));
 connect(tensionerFlange_TP, doubleLeverTP.flange_b) 
annotation(points=[232,201; 232,96.654; 335.354,96.654],
                                                style(color=0,
rgbcolor={0,0,0}));
    
// draw graphics on icon layer
annotation (Icon(Ellipse(extent=[253.193,87.3081; 303.193,137.308], style(
 color=0,
 rgbcolor={0,0,0},
 fillColor=30,
 rgbfillColor={215,215,215})),
Ellipse(extent=[188.2,-3.3; 263.2,71.7], style(
 color=0,
 rgbcolor={0,0,0},
 fillColor=30,
 rgbfillColor={215,215,215})),
Ellipse(extent=[327.5,7.5; 392.5,72.5], style(
 color=0,
 rgbcolor={0,0,0},
 fillColor=30,
 rgbfillColor={215,215,215})),
Ellipse(extent=[239,-79; 322,6],          style(
 color=0,
 rgbcolor={0,0,0},
 fillColor=30,
 rgbfillColor={215,215,215})),
Ellipse(extent=[124.1,-177.7; 239.1,-62.7], style(
 color=0,
 rgbcolor={0,0,0},
 fillColor=30,
 rgbfillColor={215,215,215})),
Ellipse(extent=[-70,-70; 70,70], style(
 color=0,
 rgbcolor={0,0,0},
 fillColor=30,
 rgbfillColor={215,215,215})),
Ellipse(extent=[60,30; 160,130], style(
 color=0,
 rgbcolor={0,0,0},
 fillColor=30,
 rgbfillColor={215,215,215})),
Text(
extent=[268.193,132.308; 288.193,117.308],
 style(
 color=0,
 rgbcolor={0,0,0}),
 string="TP"),
Text(
extent=[215.7,64.2; 235.7,41.7],
 style(
 color=0,
 rgbcolor={0,0,0}),
 string="IP"),
Text(
extent=[350,66; 370,46.5],
 style(
 color=0,
 rgbcolor={0,0,0}),
 string="AL"),
Text(
extent=[272.5,1.3; 292.5,-31.7],
 style(
 color=0,
 rgbcolor={0,0,0}),
 string="WP"),
Text(
extent=[171.6,-74.2; 191.6,-108.7],
 style(
 color=0,
 rgbcolor={0,0,0}),
 string="AC"),
Text(
extent=[-10,56; 10,14],
 style(
 color=0,
 rgbcolor={0,0,0}),
 string="CR"),
Text(
extent=[100,120; 120,90],
 style(
 color=0,
 rgbcolor={0,0,0}),
 string="PS"),
Line(points=[88.1689,35.0177; 30.5635,62.9752], style(
 color=1,
 rgbcolor={255,0,0},
 thickness=1,
 fillColor=9,
 rgbfillColor={175,175,175},
 fillPattern=1)),
Line(points=[-35.2218,-60.4932; 152.668,-169.891], style(
 color=1,
 rgbcolor={255,0,0},
 thickness=1,
 fillColor=9,
 rgbfillColor={175,175,175},
 fillPattern=1)),
Line(points=[239.099,-120.525; 238,-38],          style(
 color=1,
 rgbcolor={255,0,0},
 thickness=1,
 fillColor=9,
 rgbfillColor={175,175,175},
 fillPattern=1)),
Line(points=[284,6; 361.068,7.51754],           style(
 color=1,
 rgbcolor={255,0,0},
 thickness=1,
 fillColor=9,
 rgbfillColor={175,175,175},
 fillPattern=1)),
Line(points=[341.895,66.9898; 246.591,3.05794], style(
 color=1,
 rgbcolor={255,0,0},
 thickness=1,
 fillColor=9,
 rgbfillColor={175,175,175},
 fillPattern=1)),
Line(points=[216.323,70.5086; 284.444,88.1024], style(
 color=1,
 rgbcolor={255,0,0},
 thickness=1,
 fillColor=9,
 rgbfillColor={175,175,175},
 fillPattern=1)),
Line(points=[263.202,132.315; 139.982,39.9866], style(
 color=1,
 rgbcolor={255,0,0},
 thickness=1,
 fillColor=9,
 rgbfillColor={175,175,175},
 fillPattern=1)),
Line(points=[186,-17; 254.596,22.4239], style(
 color=2,
 rgbcolor={0,255,0},
 arrow=0)),
Line(points=[254.596,22.4239; 232,201], style(
 color=0,
 rgbcolor={0,0,0},
 thickness=1)),
Line(points=[232,201; 278.193,112.308],style(
 color=0,
 rgbcolor={0,0,0},
 thickness=1)),
Polygon(points=[232,201; 222,186; 242,186; 232,201], style(
 color=0,
 rgbcolor={0,0,0},
 fillColor=10,
 rgbfillColor={135,135,135})),
Line(points=[224,186; 220,182], style(color=0, rgbcolor= {0,0,0})),
Line(points=[228,186; 224,182], style(color=0, rgbcolor= {0,0,0})),
Line(points=[232,186; 228,182], style(color=0, rgbcolor= {0,0,0})),
Line(points=[236,186; 232,182], style(color=0, rgbcolor= {0,0,0})),
Line(points=[240,186; 236,182], style(color=0, rgbcolor= {0,0,0})),
Polygon(points=[186,-17; 176,-32; 196,-32; 186,-17], style(
 color=0,
 rgbcolor={0,0,0},
 fillColor=10,
 rgbfillColor={135,135,135})),
Line(points=[178,-32; 174,-36], style(color=0, rgbcolor= {0,0,0})),
Line(points=[182,-32; 178,-36], style(color=0, rgbcolor= {0,0,0})),
Line(points=[186,-32; 182,-36], style(color=0, rgbcolor= {0,0,0})),
Line(points=[190,-32; 186,-36], style(color=0, rgbcolor= {0,0,0})),
Line(points=[194,-32; 190,-36], style(color=0, rgbcolor= {0,0,0}))));
  connect(TP.frame_b, fixedTranslation.frame_a) annotation (points=[278.096,
          98.6772; 296,98.6772; 296,114; 305,114],
                                                 style(
      color=10,
      rgbcolor={95,95,95},
      thickness=2));
    
  connect(doubleLeverTP.frame_c, springDamperParallelTP.frame_a) annotation (
      points=[356.839,96.654; 356.839,122; 407.096,122; 407.096,116], style(
      color=10,
      rgbcolor={95,95,95},
      thickness=2));
  connect(doubleLeverTP.frame_a1, springDamperParallelTP.frame_b) annotation (
      points=[356.839,85.6465; 356.839,72; 407.096,72; 407.096,79.8081], style(
      color=10,
      rgbcolor={95,95,95},
      thickness=2));
  connect(fixedTranslation.frame_b, doubleLeverTP.frame_b) annotation (points=[337,114;
          346,114; 346,114.266; 346.096,114.266],        style(
      color=10,
      rgbcolor={95,95,95},
      thickness=2));
  connect(IP_TP.spanConnector_a, wrapAngle_IP.spanConnector_b) annotation (
      points=[258.193,66.2; 209.105,66.2; 209.105,36.83], style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(wrapAngle_AL.spanConnector_a, WP_AL.spanConnector_b) annotation (
      points=[360.5,56; 393.071,56; 393.071,-32.6289], style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(wrapAngle_WP.spanConnector_b, WP_AL.spanConnector_a) annotation (
      points=[296.625,-33.305; 297.313,-33.305; 297.313,-46.7711; 378.929,
          -46.7711],
                   style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(wrapAngle_WP.spanConnector_a, AC_WP.spanConnector_b) annotation (
      points=[277.875,-18.395; 256.571,-18.395; 256.571,-133.129], style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(wrapAngle_AC.spanConnector_b, AC_WP.spanConnector_a) annotation (
      points=[163.24,-116.03; 163.24,-147.271; 242.429,-147.271], style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(CR_AC.spanConnector_a, wrapAngle_CR.spanConnector_b) annotation (
      points=[164.529,-38.9289; -17.2,-38.9289; -17.2,10.7], style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(wrapAngle_PS.spanConnector_a, TP_PS.spanConnector_b) annotation (
      points=[108.6,96.3; 108.6,115.308; 131,115.308], style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
end Layout;
  
public 
  Modelica.Mechanics.Rotational.Sensors.SpeedSensor speedSensor_CR 
    annotation (extent=[-80,-62; -60,-42], rotation=270);
  Modelica.Mechanics.Rotational.Sensors.SpeedSensor speedSensor_AC 
    annotation (extent=[-60,-62; -40,-42], rotation=270);
  Modelica.Mechanics.Rotational.Sensors.SpeedSensor speedSensor_WP 
    annotation (extent=[-40,-62; -20,-42], rotation=270);
  Modelica.Mechanics.Rotational.Sensors.SpeedSensor speedSensor_AL 
    annotation (extent=[-20,-62; 0,-42], rotation=270);
  Modelica.Mechanics.Rotational.Sensors.SpeedSensor speedSensor_TP 
    annotation (extent=[0,-62; 20,-42], rotation=270);
equation 
  connect(load.flange_b,quadraticSpeedDependentTorque. flange) 
    annotation (points=[52,37; 65,37],   style(color=0, rgbcolor={0,0,0}));
  connect(world.frame_b,actuatedRevolute. frame_a) annotation (points=[-58,73;
        -58,38; -52,38],         style(
      color=10,
      rgbcolor={95,95,95},
      thickness=2));
  connect(world.frame_b, cylinder_modified1.frame_a)  annotation (points=[-58,73; 
        -58,76.7733; -19.6,76.7733],     style(
      color=10,
      rgbcolor={95,95,95},
      thickness=2));
  connect(cylinder_modified1.frame_a1, actuatedRevolute.frame_b)  annotation (
      points=[-19.8933,60.7867; -28,60.7867; -28,38; -32,38], style(
      color=10,
      rgbcolor={95,95,95},
      thickness=2));
  connect(cylinder_modified1.frame_a2, cylinder_modified2.frame_a) 
    annotation (points=[-4.86,76.7733; -2,77; 6.4,76.7733], style(
      color=10,
      rgbcolor={95,95,95},
      thickness=2));
  connect(cylinder_modified1.frame_a3, cylinder_modified2.frame_a1) 
    annotation (points=[-4.86,60.7867; -2,61; 6.10667,60.7867], style(
      color=10,
      rgbcolor={95,95,95},
      thickness=2));
  connect(cylinder_modified2.frame_a2, cylinder_modified3.frame_a) 
    annotation (points=[21.14,76.7733; 28,77; 32.4,76.7733], style(
      color=10,
      rgbcolor={95,95,95},
      thickness=2));
  connect(cylinder_modified2.frame_a3, cylinder_modified3.frame_a1) 
    annotation (points=[21.14,60.7867; 26,61; 32.1067,60.7867], style(
      color=10,
      rgbcolor={95,95,95},
      thickness=2));
  connect(cylinder_modified3.frame_a2, cylinder_modified4.frame_a) 
    annotation (points=[47.14,76.7733; 50,77; 58.4,76.7733], style(
      color=10,
      rgbcolor={95,95,95},
      thickness=2));
  connect(cylinder_modified3.frame_a3, cylinder_modified4.frame_a1) 
    annotation (points=[47.14,60.7867; 52,61; 58.1067,60.7867], style(
      color=10,
      rgbcolor={95,95,95},
      thickness=2));
  connect(actuatedRevolute.axis, AccessoryDrive.flange_CR) annotation (points=[-42,28; 
        -42,10.6371; -14.7733,10.6371],                 style(color=0, rgbcolor=
         {0,0,0}));
  connect(AccessoryDrive.flange_CR, load.flange_a) annotation (points=[-14.7733,
        10.6371; -14.7733,37; 37,37], style(color=0, rgbcolor={0,0,0}));
  connect(speedSensor_CR.flange_a, AccessoryDrive.flange_CR) annotation (points=[-70,-42; 
        -70,4; -14.7733,4; -14.7733,10.6371],          style(color=0, rgbcolor=
          {0,0,0}));
  connect(speedSensor_AC.flange_a, AccessoryDrive.flange_AC) annotation (points=[-50,-42; 
        -50,-6; 5.24302,-6; 5.24302,-3.42427],          style(color=0, rgbcolor=
         {0,0,0}));
  connect(speedSensor_WP.flange_a, AccessoryDrive.flange_WP) annotation (points=[-30,-42; 
        -30,-14; 16.144,-14; 16.144,6.34385],            style(color=0,
        rgbcolor={0,0,0}));
  connect(speedSensor_AL.flange_a, AccessoryDrive.flange_AL) annotation (points=[-10,-42; 
        -10,-24; 24.9067,-24; 24.9067,15.3165],          style(color=0,
        rgbcolor={0,0,0}));
  connect(speedSensor_TP.flange_a, AccessoryDrive.flange_TP) annotation (points=[10,-42; 
        10,-34; 34,-34; 34,23.7753; 15.8897,23.7753],         style(color=0,
        rgbcolor={0,0,0}));
end PassengerCarAccessoryDrive;
