model SimpleBelt "Getting started example" 
  
  annotation (Documentation(info="<HTML>
<p>
 This is the <a href=\"Modelica://Belts.UsersGuide.GettingStarted\">Getting Started</a> example for this library. It's recommended to start
 with this model. See <a href=\"Modelica://Belts.UsersGuide.GettingStarted\">Getting Started</a> for more information. 
 By default the animation of the green hubload vectors and the blue span force vectors is enabled. <br>
 Pulley2 is charged with a ramp velocity excitation, this means that the rotational speed of the left pulley is increasing linearly.<br>
 For simulation you can either select the simulation button <IMG SRC=\"../Pics/simulation.PNG\"> or <b>Commands</b> and <b>span forces in 
 the belt in [N]</b>. <br>
 After the simulation of the model, it's possible to display the span forces, the rotational angle of the pulleys, the rotational velocities 
 of the pulleys and the input velocity automatically by selecting <b>Commands</b> and <b>span forces in the belt in [N]</b>, and so on. For a
 nice animation select <b>Speed: 0.25</b> in the animation speed pull down menu of the <b>Simulation tab</b>. 
</p>
<p>
  <IMG SRC=\"../Pics/simpleBelt.PNG\"
</p>
</HTML>
"), Diagram,
    Commands(
      executeCall(ensureSimulated=true) = plot({"span2.SpanForce",
        "span3.SpanForce"}) "span force in the belt in [N]",
      executeCall(ensureSimulated=true) = plot({"Pulley1.pulleyInertia.phi",
        "Pulley2.pulleyInertia.phi"}) 
        "rotational angle of the pulleys in [rad]",
      executeCall(ensureSimulated=true) = plot({"Pulley1.pulleyInertia.w",
        "Pulley2.pulleyInertia.w"}) 
        "rotational velocity of the pulley in [rad/s]",
      executeCall(ensureSimulated=true) = plot({"speed.w"}) 
        "rotational input velocity in [rad/s]"));
 extends Modelica.Icons.Example;
  annotation (uses(Belts(version="1.0"), Modelica(version="2.2.1")),
                                          Diagram);
  
  ModelElements.FixedPulley Pulley2(position={-0.2,0},
    redeclare Belts.Visualizers.Pulleys.PulleyBoard pulleyShape,
    redeclare model ContactModel = Belts.ContactModels.FlatBelt,
    showPulley=true,
    showMarker=true)                annotation (extent=[-80,2; -40,42]);
  ModelElements.FixedPulley Pulley1(position={0.3,0}, diameter=0.2,
    redeclare Belts.Visualizers.Pulleys.PulleyBoard pulleyShape,
    redeclare model ContactModel = Belts.ContactModels.FlatBelt,
    showMarker=true)                                               annotation (extent=[40,0; 80,40]);
  inner Modelica.Mechanics.MultiBody.World world(animateWorld=false,
      animateGravity=false,
    enableAnimation=true) 
    annotation (extent=[-94,86; -84,96]);
  ModelElements.WrapAngle wrapAngle(h=Belts.Defaults.height) 
    annotation (extent=[54,-34; 94,6], rotation=180);
  ModelElements.Span span2(
    h=Belts.Defaults.height,
    modeShapes=3,
    InitialElongation=0.001) 
                           annotation (extent=[-20,20; 20,60], rotation=180);
  ModelElements.WrapAngle wrapAngle3 annotation (extent=[-94,14; -54,54]);
  ModelElements.Span span3(modeShapes=3, InitialElongation=0.001) 
                           annotation (extent=[-20,-40; 20,0], rotation=0);
  Modelica.Mechanics.Rotational.Speed speed 
    annotation (extent=[-54,-48; -34,-28], rotation=90);
  Modelica.Blocks.Sources.Ramp ramp(duration=1, height=50) 
    annotation (extent=[-70,-76; -50,-56]);
equation 
  connect(wrapAngle.wrapAngleConnector_b,Pulley1. wrapAngleConnector_a) 
    annotation (points=[76.4,-16; 76,-16; 76,36; 51.6,36; 51.6,28.4], style(
      color=0,
      rgbcolor={50,50,50},
      pattern=3,
      thickness=2,
      fillColor=1,
      rgbfillColor={255,0,0},
      fillPattern=1));
  connect(span2.spanConnector_a, wrapAngle.spanConnector_b) annotation (points=[20,40;
        80,40; 80,-8],         style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2,
      fillColor=1,
      rgbfillColor={255,0,0},
      fillPattern=1));
  connect(wrapAngle3.spanConnector_a, span2.spanConnector_b) annotation (points=
       [-68,40; -20,40], style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2,
      fillColor=1,
      rgbfillColor={255,0,0},
      fillPattern=1));
  connect(span3.spanConnector_b, wrapAngle.spanConnector_a) annotation (points=[20,-20;
        68,-20],          style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2,
      fillColor=1,
      rgbfillColor={255,0,0},
      fillPattern=1));
  connect(wrapAngle3.spanConnector_b, span3.spanConnector_a) annotation (points=
       [-80,28; -80,-20; -20,-20], style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2,
      fillColor=1,
      rgbfillColor={255,0,0},
      fillPattern=1));
  connect(Pulley2.wrapAngleConnector_a, wrapAngle3.wrapAngleConnector_b) 
    annotation (points=[-68.4,30.4; -68.4,32.2; -76.4,32.2; -76.4,36], style(
      color=0,
      rgbcolor={50,50,50},
      pattern=3,
      thickness=2,
      fillColor=1,
      rgbfillColor={255,0,0},
      fillPattern=1));
  connect(Pulley2.flange_b, speed.flange_b) annotation (points=[-60,22; -44,22;
        -44,-28], style(color=0, rgbcolor={0,0,0}));
  connect(ramp.y, speed.w_ref) annotation (points=[-49,-66; -44,-66; -44,-50],
      style(color=74, rgbcolor={0,0,127}));
end SimpleBelt;
