model VibratingSpans "Belt drive example with transversal span vibrations" 
  annotation (Documentation(info="<HTML>
<p>
 Advanced example for the use of excitation in belt drives. The rotational angle of the left pulley is excited by a sine signal with a 
 frequency of 150 Hz.<br>
 For simulation you can either select the simulation button <IMG SRC=\"../Pics/simulation.PNG\"> or <b>Commands</b> and <b>span forces in 
 the belt in [N]</b>. <br>
 After the simulation of the model, it's possible to display the rotational position, rotational velocities and the span forces automatically 
 by selecting <b>Commands</b> and <b>rotational position of the pulleys in [rad]</b>, and so on. For an appropriate animation speed select 
 <b>Speed: 0.01</b> in the animation speed pull down menu of the <b>Simulation tab</b>. 
</p>
<p>
  <IMG SRC=\"../Pics/VibratingSpansExample.PNG\"
</p>
</HTML>
"), Diagram,
    Commands(
      executeCall(ensureSimulated=true) = plot({"Pulley1.pulleyInertia.phi",
        "Pulley2.pulleyInertia.phi","Pulley3.pulleyInertia.phi"}) 
        "rotational position of the pulleys in [rad]",
      executeCall(ensureSimulated=true) = plot({"Pulley1.pulleyInertia.w",
        "Pulley2.pulleyInertia.w","Pulley3.pulleyInertia.w"}) 
        "rotational velocity of the pulleys in [rad/s]",
      executeCall(ensureSimulated=true) = plot({"span_P1_P2.SpanForce",
        "span_P2_P3.SpanForce","span_P3_P1.SpanForce"}) 
        "span forces in the belt in [N]"),
    experiment(StopTime=0.15),
    experimentSetupOutput);
  extends Modelica.Icons.Example;
  inner Modelica.Mechanics.MultiBody.World world(animateWorld=false,
    animateGravity=false,
    enableAnimation=true) 
    annotation (extent=[-94,86; -84,96]);
  ModelElements.FixedPulley Pulley2(
    animateTorque=false,
    inertia=0.001,
    animateHubloads=false,
    position={-0.2,0},
    redeclare Belts.Visualizers.Pulleys.BasicPulley pulleyShape,
    redeclare model ContactModel = Belts.ContactModels.ToothBelt,
    showMarker=true) 
    annotation (extent=[-60,40; -40,60]);
  ModelElements.FixedPulley Pulley1(
    animateTorque=false,
    inertia=0.001,
    animateHubloads=false,
    position={0.2,0},
    redeclare Belts.Visualizers.Pulleys.BasicPulley pulleyShape,
    redeclare model ContactModel = Belts.ContactModels.ToothBelt,
    showMarker=true) 
    annotation (extent=[40,40; 60,60], rotation=0);
  ModelElements.FixedPulley Pulley3(
    animateTorque=false,
    inertia=0.001,
    animateHubloads=false,
    position={-0.05,-0.1},
    redeclare Belts.Visualizers.Pulleys.BasicPulley pulleyShape,
    redeclare model ContactModel = Belts.ContactModels.ToothBelt,
    showMarker=true) 
    annotation (extent=[-10,-20; 10,0],
                                      rotation=180);
  ModelElements.WrapAngle wrapAngle_P2(redeclare 
      Belts.Visualizers.BeltShapes.RoundEdge beltShape) 
    annotation (extent=[-47,67; -67,47],rotation=180);
  ModelElements.WrapAngle wrapAngle_P1(redeclare 
      Belts.Visualizers.BeltShapes.RoundEdge beltShape) 
    annotation (extent=[67,67; 47,47],rotation=90);
  ModelElements.WrapAngle wrapAngle_P3(redeclare 
      Belts.Visualizers.BeltShapes.RoundEdge beltShape) 
    annotation (extent=[-10,-30; 10,-10],rotation=135);
  ModelElements.Span span_P1_P2(
    animationPoints=50,
    modeShapes=3,
    redeclare Belts.Visualizers.BeltShapes.RoundEdge beltShape) 
    annotation (extent=[-10,50; 10,70],rotation=180);
  ModelElements.Span span_P2_P3(animateSpanForces=false, redeclare 
      Belts.Visualizers.BeltShapes.RoundEdge beltShape,
    animationPoints=5) 
    annotation (extent=[-63,-23; -43,-3],rotation=315);
  ModelElements.Span span_P3_P1(animateSpanForces=false, redeclare 
      Belts.Visualizers.BeltShapes.RoundEdge beltShape) 
    annotation (extent=[43,-23; 63,-3],rotation=45);
  Modelica.Mechanics.Rotational.Position position(exact=true) 
    annotation (extent=[-60,-60; -40,-80],rotation=180);
  Modelica.Blocks.Sources.Sine sine(
    amplitude=6.28/360*0.5,
    freqHz=150) 
    annotation (extent=[-10,-60; 10,-80],
                                        rotation=180);
  
equation 
  connect(position.phi_ref, sine.y) 
    annotation (points=[-38,-70; -11,-70],
                style(color=74, rgbcolor={0,0,127}));
  annotation (Diagram);
  connect(span_P1_P2.spanConnector_a, wrapAngle_P1.spanConnector_b) 
                                                            annotation (points=[10,60;
        54,60],                       style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(wrapAngle_P1.spanConnector_a, span_P3_P1.spanConnector_b) 
                                                             annotation (points=[60,54; 
        60,-5.92893; 60.0711,-5.92893],                    style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(span_P3_P1.spanConnector_a, wrapAngle_P3.spanConnector_b) 
                                                             annotation (points=[45.9289,
        -20.0711; 24.9644,-20.0711; 24.9644,-20; 4.24264,-20],         style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(wrapAngle_P3.spanConnector_a, span_P2_P3.spanConnector_b) 
                                                             annotation (points=[-4.24264,
        -20; -25.0858,-20; -25.0858,-20.0711; -45.9289,-20.0711],
      style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(wrapAngle_P2.spanConnector_b, span_P2_P3.spanConnector_a) 
                                                            annotation (points=[-60,54; 
        -60,-5.92893; -60.0711,-5.92893],          style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(wrapAngle_P2.wrapAngleConnector_b, Pulley2.wrapAngleConnector_a) 
    annotation (points=[-58.2,58; -58.2,58; -56,54.2; -54.2,54.2], style(
      color=0,
      rgbcolor={50,50,50},
      pattern=3,
      thickness=2));
  connect(Pulley1.wrapAngleConnector_a, wrapAngle_P1.wrapAngleConnector_b) 
    annotation (points=[45.8,54.2; 46,54; 46,58.2; 58,58.2],
                                                           style(
      color=0,
      rgbcolor={50,50,50},
      pattern=3,
      thickness=2));
  connect(Pulley3.wrapAngleConnector_a, wrapAngle_P3.wrapAngleConnector_b) 
    annotation (points=[4.2,-14.2; 4.2,-18; 0,-18; 0,-21.5556; 0.141421,
        -21.5556], style(
      color=0,
      rgbcolor={50,50,50},
      pattern=3,
      thickness=2));
  connect(span_P1_P2.spanConnector_b, wrapAngle_P2.spanConnector_a) annotation (
     points=[-10,60; -54,60],style(
      color=1,
      rgbcolor={255,0,0},
      pattern=3,
      thickness=2));
  connect(position.flange_b, Pulley2.flange_b) annotation (points=[-60,-70; -80,
        -70; -80,50; -50,50], style(color=0, rgbcolor={0,0,0}));
end VibratingSpans;
