function computeWrapAngle "Compute wrap angle" 
  
    annotation (Documentation(info="<HTML>
This function calculates the <b>wrap angle</b> of a pulley.
<br><br>
</HTML>
"));
  
  import Belts.Functions.absVec;
  import Modelica.Constants.pi;
  import Modelica.Math.acos;
  input Real theVec[3] 
    "3-dimensional vector from pulley center to outgoing contact point";
  input Real SpanVec2D_a[2] "2-dimensional vector of incoming span";
  input Real SpanVec2D_b[2] "2-dimensional vector of outgoing span";
  output Real WrapAngle "wrap angle";
  
algorithm 
  //scalar product theVec*SpanVec (2-dimensional)
  WrapAngle := ({theVec[1],theVec[2]} * SpanVec2D_a)/(absVec({theVec[1],theVec[2]})*absVec(SpanVec2D_a));
  
  if WrapAngle > 0 then
      WrapAngle := 2*pi - acos((SpanVec2D_a * SpanVec2D_b)/(absVec(SpanVec2D_a)*absVec(SpanVec2D_b)));
  else
      WrapAngle := acos((SpanVec2D_a * SpanVec2D_b)/(absVec(SpanVec2D_a)*absVec(SpanVec2D_b)));
  end if;
  
end computeWrapAngle;
