partial model PartialPulley "Base class for a pulley" 
  import Modelica.Constants.pi;
  
    replaceable model ContactModel = Belts.ContactModels.FlatBelt extends 
    Belts.Interfaces.PartialContactModel 
    "Contact model for pulley-belt contact" 
                             annotation (choicesAllMatching= true, Diagram);
  
extends ContactModel(
  spanForceVec_a=wrapAngleConnector_a.spanForceVec_a,
  spanForceVec_b=wrapAngleConnector_a.spanForceVec_b,
  spanLength_a=wrapAngleConnector_a.spanLength_a,
  spanLength_b=wrapAngleConnector_a.spanLength_b,
  wrapAngle=wrapAngleConnector_a.WrapAngle,
  redeclare final constant Modelica.SIunits.Mass beltMass = Belts.Defaults.Mass,
  redeclare final parameter Modelica.SIunits.Diameter pulleyDiameter=diameter,
  redeclare final parameter Modelica.SIunits.AngularVelocity slip_w_start =  w_start);
  annotation (Documentation(info="<HTML>
 <p>
  <IMG SRC=\"../Pics/FreePulley.png\"
</p> 
<p>
<p>
This model element describes a pulley with a variable rotation axis.<br>
Calculated is the momentum equality in the rotation axis wich is limited to the eytelwein torque.<br>
If the calculated torque acting on the pulley exceeds then the eytelwein equation only this torqe will be transmitted.<br>
See equation below where Fmax and Fmin are the span forces.
</p>
<p>
  <IMG SRC=\"../Pics/PulleyEq.JPG\"
</p>
<p>
Click <a href=\"..\UsersGuide\Dynamic Simulation of Automobile Accessory Drives.pdf\">
<b>here</b></a> for more information.
</HTML>
"), Diagram,
    Icon(
    Text(
      extent=[0,-100; 0,-142],
      string="%name",
        style(color=0, rgbcolor={0,0,0}))));
  
  annotation (Icon(
    Text(
      extent=[-100,-90; 100,-130],
      string="%name",
      style(color=0)),
    Ellipse(extent=[-20,20; 20,-20], style(
      color=0,
      rgbcolor={0,0,0},
      pattern=2)),
    Line(points=[0,-70; 0,-20], style(
      color=0,
      rgbcolor={0,0,0},
      pattern=2))),
    Diagram,
    DymolaStoredErrors);
  
public 
  parameter Boolean inside = true "pulley position at belt" 
      annotation(Dialog(group="location"));
  
  parameter Modelica.SIunits.AngularVelocity w_start=0 
    "initial value angular velocity" 
      annotation(Dialog(group="Initial"));
  parameter Boolean useInitialPosition = false 
    "set true is you want to give the pully an initial position" 
    annotation(Dialog(group="Initial"));
  parameter Real initialPosition[3] = {0,0,0} "initial pulley position" 
 annotation(Dialog(group="Initial",enable=useInitialPosition));
  
  parameter Modelica.SIunits.Diameter diameter = Belts.Defaults.diameter 
    "pulley diameter";
  parameter Modelica.SIunits.Mass mass = Belts.Defaults.Mass "pulley mass";
  parameter Modelica.SIunits.Inertia inertia = Belts.Defaults.Inertia 
    "pulley inertia";
  
  parameter Boolean showPulley = true "animate pulley" annotation(Dialog(tab="Animation"));
  // pulley  ANIMATION
  replaceable Belts.Visualizers.Pulleys.BasicPulley pulleyShape(
     position=frame_b.r_0,
     diameter= diameter,
     rotation = flangePulley.phi,
     beltHeight= wrapAngleConnector_a.spanHeight,
     zCoordinate =  wrapAngleConnector_a.z,
     width =  wrapAngleConnector_a.width,
     animate = world.enableAnimation and showPulley,
     specularCoefficient = specularCoefficient,
     color = color) extends Belts.Interfaces.PartialPulleyShape(
     position=frame_b.r_0,
     diameter= diameter,
     rotation= flangePulley.phi,
     beltHeight= wrapAngleConnector_a.spanHeight,
     animate = world.enableAnimation and showPulley,
     zCoordinate =  wrapAngleConnector_a.z,
     width =  wrapAngleConnector_a.width,
     specularCoefficient = specularCoefficient,
     color = color) "pulley shape" annotation(Dialog(tab="Animation", enable= showPulley),choicesAllMatching= true);
  parameter Modelica.Mechanics.MultiBody.Types.Color color = Belts.Defaults.PulleyColor 
    "pulley color" 
    annotation(Dialog(tab="Animation", enable= showPulley));
  parameter Modelica.Mechanics.MultiBody.Types.SpecularCoefficient 
    specularCoefficient= Belts.Defaults.specularCoefficient 
    "reflection of ambient light (= 0: light is completely absorbed)" 
    annotation (Dialog(tab="Animation", enable= showPulley));
  
 parameter Boolean animateHubloads = true "show hubload vector" 
    annotation(Dialog(tab="Animation", group="hubloads", enable= showPulley));
  parameter Belts.Types.ForceScalingFactor hubloadScale = Belts.Defaults.hubloadScale 
    "scaling factor for hubload vector" 
    annotation(Dialog(tab="Animation", group="hubloads", enable=animateHubloads and showPulley));
  parameter Modelica.Mechanics.MultiBody.Types.Color hubloadColor = Belts.Defaults.hubloadColor 
    "color of arrow representing the hubload vector" 
    annotation(Dialog(tab="Animation", group="hubloads", enable=animateHubloads and showPulley));
 parameter Modelica.SIunits.Diameter hubloadDiameter = Belts.Defaults.hubloadDiameter 
    "diameter of arrow representing the hubload vector" 
    annotation(Dialog(tab="Animation", group="hubloads", enable=animateHubloads and showPulley));
  
  parameter Boolean animateTorque = true "show torque vector" 
    annotation(Dialog(tab="Animation", group="torque", enable= showPulley));
  parameter Belts.Types.TorqueScalingFactor torqueScale = Belts.Defaults.torqueScale 
    "scaling factor for torque vector" 
    annotation(Dialog(tab="Animation", group="torque", enable=animateTorque and showPulley));
  parameter Modelica.Mechanics.MultiBody.Types.Color positiveTorqueColor = Belts.Defaults.positiveTorqueColor 
    "color of arrow representing a positive torque vector" 
    annotation(Dialog(tab="Animation", group="torque", enable=animateTorque and showPulley));
  parameter Modelica.Mechanics.MultiBody.Types.Color negativeTorqueColor = Belts.Defaults.negativeTorqueColor 
    "color of arrow representing a negative torque vector" 
    annotation(Dialog(tab="Animation", group="torque", enable=animateTorque and showPulley));
  parameter Modelica.SIunits.Diameter torqueDiameter = Belts.Defaults.torqueDiameter 
    "diameter of arrow representing the hubload vector" 
    annotation(Dialog(tab="Animation", group="torque", enable=animateTorque and showPulley));
  
   parameter Boolean showMarker= false 
    "set true if you want a position marker on the pulley" 
    annotation(Dialog(tab="Animation", group="position marker", enable= showPulley));
  parameter Modelica.SIunits.Diameter markerDiameter = Belts.Defaults.markerDiameter 
    "diameter of cylinder representing the position markers" 
    annotation(Dialog(tab="Animation", group="position marker", enable=showMarker and showPulley));
  
  parameter Modelica.Mechanics.MultiBody.Types.Color pulleyMarkerColor = Belts.Defaults.pulleyMarkerColor 
    "color of cylinder representing the pulley position marker" 
  annotation(Dialog(tab="Animation", group="position marker", enable=showMarker and showPulley));
 parameter Modelica.Mechanics.MultiBody.Types.Color beltMarkerColor = Belts.Defaults.beltMarkerColor 
    "color of cylinder representing the belt position marker" 
 annotation(Dialog(tab="Animation", group="position marker", enable=showMarker and showPulley));
  
  Modelica.SIunits.Angle phi;
  
  Interfaces.WrapAngleConnector_a wrapAngleConnector_a "wrap angle" 
    annotation (extent=[-52,32; -32,52]);
  Modelica.Mechanics.MultiBody.Interfaces.Frame_b frame_b 
    "mounting point of the pulley" 
    annotation (extent=[-10,-90;10,-70]);
  Modelica.Mechanics.MultiBody.Parts.Rotor1D pulleyInertia(
    n={0,0,1},
    J=inertia,
    animation=false,
    w(start=w_start)) "pulley inertia" 
   annotation (extent=[30,-10; 10,10]);
  Modelica.Mechanics.Rotational.Torque torque annotation (extent=[-80,60; -60,
        80],
      rotation=0);
  Modelica.Mechanics.MultiBody.Forces.FrameForce frameForce(
    animation=false) 
    annotation (extent=[-54,-10; -34,10]);
  Modelica.Mechanics.MultiBody.Parts.Fixed mountingPoint 
    annotation (extent=[-64,-54; -44,-34]);
  Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_b 
    "rotational connection to the pulley axis" 
    annotation (extent=[-10,-10; 10,10]);
  Modelica.Mechanics.MultiBody.Parts.Body body(
    m=mass,
    animation=false,
    I_11=0,
    I_22=0,
    I_33=0,
    initType=initType,
    r_0_start=initialPosition) "pulley mass" 
    annotation (extent=[-10,-52; 10,-32], rotation=90);
  
  // torque vector 
  Modelica.Mechanics.MultiBody.Visualizers.Advanced.DoubleArrow torqueVector(color = if flange_b.tau > 0 then positiveTorqueColor else negativeTorqueColor,
    r_head = {0, 0, abs(flange_b.tau * torqueScale)},
    r = {wrapAngleConnector_a.PulleyPosition[1], wrapAngleConnector_a.PulleyPosition[2], wrapAngleConnector_a.z + wrapAngleConnector_a.width * 0.6},
    diameter = torqueDiameter) if world.enableAnimation and showPulley and animateTorque;
  
  // hubload vector 
  Modelica.Mechanics.MultiBody.Visualizers.Advanced.Arrow hubloadVector(color = hubloadColor,
    r_head = {wrapAngleConnector_a.f[1] * hubloadScale, wrapAngleConnector_a.f[2] * hubloadScale, 0},
    r = {wrapAngleConnector_a.PulleyPosition[1], wrapAngleConnector_a.PulleyPosition[2], wrapAngleConnector_a.z + wrapAngleConnector_a.width * 0.6},
    diameter = hubloadDiameter) if world.enableAnimation and showPulley and animateHubloads;
  
protected 
  outer Modelica.Mechanics.MultiBody.World world;
  parameter Integer direction = if inside then -1 else +1 
    "nominal direction of pulley rotation";
  parameter Modelica.Mechanics.MultiBody.Types.Init.Temp initType= if useInitialPosition then Modelica.Mechanics.MultiBody.Types.Init.Position else Modelica.Mechanics.MultiBody.Types.Init.Free;
  
  // ************************************** 
  // Rotation frames und slip visualizers
  // **************************************
  
  Modelica.Mechanics.MultiBody.Frames.Orientation R_belt=
    Modelica.Mechanics.MultiBody.Frames.axisRotation(axis=3, angle=flangeBelt.phi, der_angle=der(flangeBelt.phi));
  Modelica.Mechanics.MultiBody.Frames.Orientation R_pulley=
    Modelica.Mechanics.MultiBody.Frames.axisRotation(axis=3, angle=flangePulley.phi, der_angle=der(flangePulley.phi));
  Modelica.Mechanics.MultiBody.Visualizers.Advanced.Shape BeltMarker(
   shapeType="cylinder",
   color=beltMarkerColor,
   r_shape={0,diameter/4,0},
   lengthDirection={0,1,0},
   widthDirection={0,0,1},
   length=diameter/4,
   width=markerDiameter,
   height=markerDiameter,
   r=frame_b.r_0 + {0, 0, wrapAngleConnector_a.width*1.2/2} + {0, 0, wrapAngleConnector_a.z},
   R = R_belt) if world.enableAnimation and showPulley and showMarker;
 Modelica.Mechanics.MultiBody.Visualizers.Advanced.Shape PulleyMarker(
   shapeType="cylinder",
   color=pulleyMarkerColor,
   r_shape={0,diameter/14,0},
   lengthDirection={0,1,0},
   widthDirection={0,0,1},
   length=diameter/4-diameter/14,
   width=markerDiameter,
   height=markerDiameter,
   r=frame_b.r_0 + {0, 0, wrapAngleConnector_a.width*1.2/2} + {0, 0, wrapAngleConnector_a.z},
   R = R_pulley) if 
                   world.enableAnimation and showPulley and showMarker;
equation 
  connect(pulleyInertia.frame_a, frame_b) 
    annotation (points=[20,-10; 20,-80; 0,-80],
                style(color=10, rgbcolor={95,95,95}, thickness=2));
  connect(frameForce.frame_b, frame_b) 
    annotation (points=[-34,0; -20,0; -20,-80; 0,-80],
                style(color=10, rgbcolor={95,95,95}, thickness=2));
  connect(frameForce.frame_resolve, mountingPoint.frame_b) 
    annotation (points=[-44,-10; -44,-44],
                style(color=10, rgbcolor={95,95,95}, pattern=3));
  connect(pulleyInertia.flange_b, flange_b) 
    annotation (points=[10,0; 0,0],
                style(color=0, rgbcolor={0,0,0}));
   connect(body.frame_a, frame_b) 
    annotation (points=[-6.12303e-016,-52; -6.12303e-016,-62; 0,-62; 0,-80],
                style(color=10,rgbcolor={95,95,95},thickness=2));
  wrapAngleConnector_a.torque = torque.tau;
  
  wrapAngleConnector_a.f = frameForce.force;
  wrapAngleConnector_a.PulleyPosition = frame_b.r_0;
  wrapAngleConnector_a.direction = direction;
  wrapAngleConnector_a.PulleyDiameter = diameter;
  wrapAngleConnector_a.Rotation = phi;
  
  // to be checked!
  wrapAngleConnector_a.Rotation = flangeBelt.phi;
  
  connect(torque.flange_b, flangeBelt) 
    annotation (points=[-60,70; -20,70], style(color=0, rgbcolor={0,0,0}));
  connect(flangePulley, pulleyInertia.flange_a) annotation (points=[40,-80; 30,
        -80; 30,0], style(color=0, rgbcolor={0,0,0}));
end PartialPulley;
