model DoubleLever "Lever assembly with two arms" 
  extends Belts.ModelElements.SingleLever;
 annotation (Documentation(info="<HTML>
<p>
  <IMG SRC=\"../Pics/DoubleLever.png\"
</p>
<p>
  The <b>DoubleLever</b> model extends the <b>SingleLever</b> model and provides an additional 
lever arm for a linear tensioning element from the 
<a href=\"Modelica://Modelica.Mechanics.MultiBody\">MultiBody</a> library. See the
 <a href=\"Modelica://Belts.Examples.PassengerCarAccessoryDrive\">accessory drive example</a> for more details.<br><br>
<b>NOTE:</b> If you intend to model a tensioner, <a href=\"http://www.ina.com\">INA</a> will provide <a href=\"Modelica://Belts.UsersGuide.Support\">customer support</a> for this library.
</p> 
</HTML>
"),Icon(
    Rectangle(extent=[-61,1; 59,-3], style(
      color=9,
      rgbcolor={175,175,175},
      fillColor=10,
      rgbfillColor={135,135,135},
      fillPattern=1)),
    Polygon(points=[60,-60; 80,-90; 40,-90; 60,-60], style(
      color=0,
      rgbcolor={0,0,0},
      thickness=2,
      fillColor=10,
      rgbfillColor={135,135,135})),
    Line(points=[80,-90; 74,-96], style(
      color=0,
      rgbcolor={0,0,0},
      thickness=2)),
    Line(points=[62,-90; 56,-96],   style(
      color=0,
      rgbcolor={0,0,0},
      thickness=2)),
    Line(points=[54,-90; 48,-96],   style(
      color=0,
      rgbcolor={0,0,0},
      thickness=2)),
    Line(points=[46,-90; 40,-96],   style(
      color=0,
      rgbcolor={0,0,0},
      thickness=2)),
    Line(points=[72,-90; 66,-96],   style(
      color=0,
      rgbcolor={0,0,0},
      thickness=2)),
    Text(
      extent=[14,-60; 48,-76],
      style(color=3, rgbcolor={0,0,255}),
      string="Mounting Point"),
    Text(
      extent=[8,12; 40,-2],
      style(color=3, rgbcolor={0,0,255}),
      string="Spring Lever")),Diagram(Text(
        extent=[22,72; 100,18],
        style(color=0, rgbcolor={0,0,0}),
        string="connect your linear tensioning element here!"), Line(points=[
            70,40; 60,8], style(
          color=0,
          rgbcolor={0,0,0},
          arrow=1,
          fillColor=0,
          rgbfillColor={0,0,0},
          fillPattern=1))));
  
  parameter Real mountingPoint[3]= {0.250,0,0} "mounting point of the spring";
  parameter Real tensionerLever[3]= {0.100,0,0} 
    "lever to the tensioning element";
  parameter Real tensionerAngle = 90 
    "angle from pulley lever to tensioner lever";
  
  Modelica.Mechanics.MultiBody.Parts.FixedTranslation fixedTranslation2(
    r= tensionerLever) 
    annotation (extent=[20,10; 40,30]);
  Modelica.Mechanics.MultiBody.Parts.FixedRotation fixedRotation1(
    n={0,0,1},
    angle= tensionerAngle) 
    annotation (extent=[-20,10; 0,30]);
  Modelica.Mechanics.MultiBody.Parts.Fixed MountingPoint(animation=false, r=
        mountingPoint) 
    annotation (extent=[20,-70; 40,-50]);
  Modelica.Mechanics.MultiBody.Interfaces.Frame_b frame_c 
    "tensioning element connector" 
    annotation (extent=[44,-16; 76,16]);
  Modelica.Mechanics.MultiBody.Interfaces.Frame_a frame_a1 
    "coordinate system fixed to the joint with one cut-force and cut-torque" 
    annotation (extent=[44,-76; 76,-44]);
  
equation 
  connect(fixedTranslation2.frame_a,fixedRotation1. frame_b) 
    annotation (points=[20,20; 0,20],
                style(color=10,rgbcolor={95,95,95},thickness=2));
  connect(MountingPoint.frame_b, frame_a1) 
    annotation (points=[40,-60; 60,-60],
                style(color=10,rgbcolor={95,95,95},thickness=2));
  connect(fixedTranslation2.frame_b, frame_c) 
    annotation (points=[40,20; 50,20;50,0; 60,0],
                style(color=10,rgbcolor={95,95,95},thickness=2));
  
  connect(fixedRotation1.frame_a, actuatedRevolute.frame_b) annotation (points=
        [-20,20; -40,20; -40,10], style(
      color=10,
      rgbcolor={95,95,95},
      thickness=2));
end DoubleLever;
