model FixedPulley "Rotatable pulley with a fixed position" 
  annotation (Documentation(info="<HTML>
 <p>
  <IMG SRC=\"../Pics/FixedPulley.png\"
</p> 
<p>
<p>
This model element describes a pulley which has a fixed position and is rotatable.<br>
The maximum transmissible momentum in the rotation axis, which is limited to the eytelwein torque, is calculated.<br>
If the calculated torque, which is acting on the pulley, exceeds the eytelwein equation only the eytelwein torque will be transmitted.<br>
Fmax and Fmin represent the span forces, see the equations in the following lines. 
</p>
<p>
  <IMG SRC=\"../Pics/PulleyEq.JPG\"
</p>
<p>
When the animation is running, it is sometimes useful to display the position markers. An increasing angle between the inner black and <br> 
the outer red postion marker indicates, that there is slippage between the belt and the pulley.<br>
If you want to make some screenshots it is nice to display some finer details of the pulley. After dragging the pulley to your modeling <br>
area, doubleclick on the pulley and select the <b>Animation</b> tab. By now it is possible to select different pulley shapes in the <br>
<b>pulleyShape</b> pull down menu. <br>Click <a href=\"..\UsersGuide\Dynamic Simulation of Automobile Accessory Drives.pdf\">
<b>here</b></a> for more information. 
</HTML>
"), Diagram);
  extends Belts.Interfaces.PartialPulley(
     redeclare final constant Boolean useInitialPosition = false,
     redeclare final constant Real initialPosition[3]= {0,0,0});
  parameter Modelica.SIunits.Position position[2] = {0, 0} 
    "vector to the pulley center";
  Modelica.Mechanics.MultiBody.Parts.Fixed fixed1(
     r = {position[1],position[2],0},
     animation=false) "fixing point of the pulley" 
    annotation (extent=[-80,-100; -60,-80],
                                         rotation=0);
  
annotation (Diagram, Icon(
    Line(points=[-20,-80; -34,-94], style(
      color=0,
      rgbcolor={0,0,0},
      thickness=2)),
    Line(points=[0,-80; -14,-94],   style(
      color=0,
      rgbcolor={0,0,0},
      thickness=2)),
    Line(points=[20,-80; 6,-94],  style(
      color=0,
      rgbcolor={0,0,0},
      thickness=2)),
    Line(points=[40,-80; 26,-94], style(
      color=0,
      rgbcolor={0,0,0},
      thickness=2)),
    Polygon(points=[0,0; 40,-80; -40,-80; 0,0], style(
      color=0,
      rgbcolor={0,0,0},
      thickness=2,
      fillColor=10,
      rgbfillColor={135,135,135}))));
  
equation 
  connect(fixed1.frame_b, frame_b) 
    annotation (points=[-60,-90; 0,-90; 0,-80],
                style(color=10, rgbcolor={95,95,95}, thickness=2));
end FixedPulley;
