model SingleLever "Lever arm assembly with one arm" 
  parameter Real pivotPoint[3]={0.150,0.100,0} "pivot point of the lever";
  parameter Real pulleyLever[3]= {0.100,0,0} "pulley lever";
  parameter Real nominalAngle = 270 "nominal angle of pulley lever";
  Modelica.Mechanics.MultiBody.Interfaces.Frame_b frame_b 
    "frame to connect the tensioner pulley" 
    annotation (extent=[-16,80; 16,112]);
  Modelica.Mechanics.MultiBody.Parts.FixedTranslation fixedTranslation1(
    r= pulleyLever) 
    annotation (extent=[-28,40; -8,60]);
  Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_b 
    "rotational axis at pivot point" 
    annotation (extent=[-70,-10; -50,10]);
  Modelica.Mechanics.MultiBody.Joints.ActuatedRevolute actuatedRevolute(
    animation=false) 
    annotation (extent=[-50,-10; -30,10], rotation=90);
  Modelica.Mechanics.MultiBody.Parts.FixedRotation NominalAngle(
    n={0,0,1},
    angle=nominalAngle) 
    annotation (extent=[-80,-60; -60,-40],rotation=90);
  Modelica.Mechanics.MultiBody.Parts.Fixed Pivot(
    animation=false,
    r=pivotPoint) 
    annotation (extent=[-80,-100; -60,-80], rotation=90);
equation 
  connect(Pivot.frame_b,NominalAngle. frame_a) 
    annotation (points=[-70,-80; -70,-60],
                style(color=10,rgbcolor={95,95,95},thickness=2));
  connect(actuatedRevolute.frame_a,NominalAngle. frame_b) 
    annotation (points=[-40,-10; -40,-40; -70,-40],
                style(color=10,rgbcolor={95,95,95},thickness=2));
  connect(actuatedRevolute.frame_b,fixedTranslation1. frame_a) 
    annotation (points=[-40,10; -40,50; -28,50],
                style(color=10,rgbcolor={95,95,95},thickness=2));
  connect(fixedTranslation1.frame_b,frame_b) 
    annotation (points=[-8,50; 0,50; 0,96],
                style(color=10,rgbcolor={95,95,95},thickness=2));
  annotation (Documentation(info="<HTML>
<p>
  <IMG SRC=\"../Pics/SingleLever.png\"
</p>
<p>
  The <b>SingleLever</b> is an assembly that can be used to model a simple tensioner by
 adding a rotary tensioning element from the 
<a href=\"Modelica://Modelica.Mechanics.Rotational\">Rotational</a> library on the pivot point.
The <a href=\"Modelica://Modelica.Mechanics.MultiBody.Interfaces.Frame_b\">frame</a> of the lever arm can be connected to a 
<a href=\"Modelica://Belts.ModelElements.FreePulley\">free pulley</a>.<br><br>
<b>NOTE:</b> If you intend to model a tensioner, <a href=\"http://www.ina.com\">INA</a> will provide <a href=\"Modelica://Belts.UsersGuide.Support\">customer support</a> for this library.
</p> 
</HTML>
"),Diagram(                                 Line(points=[-54,74; -6,
            92], style(
          color=0,
          rgbcolor={0,0,0},
          arrow=1)),                  Text(
        extent=[-78,82; -18,56],
        style(color=0, rgbcolor={0,0,0}),
        string="connect your tensioner pulley here!"),
      Line(points=[-28,-30; -56,-4], style(
          color=0,
          rgbcolor={0,0,0},
          arrow=1,
          fillColor=0,
          rgbfillColor={0,0,0},
          fillPattern=1)),            Text(
        extent=[-32,-6; 46,-66],
        style(color=0, rgbcolor={0,0,0}),
        string="connect a rotational tensioning element here!")),
                                                        Icon(
    Polygon(points=[-63,5; -1,91; 3,89; -59,1; -63,5], style(
      color=9,
      rgbcolor={175,175,175},
      fillColor=10,
      rgbfillColor={135,135,135})),
    Polygon(points=[-60,2; -40,-28; -80,-28; -60,2],  style(
      color=0,
      rgbcolor={0,0,0},
      thickness=2,
      fillColor=10,
      rgbfillColor={135,135,135})),
    Line(points=[-40,-28; -46,-34], style(
      color=0,
      rgbcolor={0,0,0},
      thickness=2)),
    Line(points=[-58,-28; -64,-34], style(
      color=0,
      rgbcolor={0,0,0},
      thickness=2)),
    Line(points=[-66,-28; -72,-34], style(
      color=0,
      rgbcolor={0,0,0},
      thickness=2)),
    Line(points=[-74,-28; -80,-34], style(
      color=0,
      rgbcolor={0,0,0},
      thickness=2)),
    Line(points=[-48,-28; -54,-34], style(
      color=0,
      rgbcolor={0,0,0},
      thickness=2)),
    Text(
      extent=[-54,72; -22,58],
      style(color=3, rgbcolor={0,0,255}),
      string="Pulley Lever"),
    Text(
      extent=[-96,18; -66,6],
      style(color=3, rgbcolor={0,0,255}),
      string="Pivot Point")));
  connect(actuatedRevolute.axis, flange_b) annotation (points=[-50,6.12303e-016; 
        -56,6.12303e-016; -56,0; -60,0], style(color=0, rgbcolor={0,0,0}));
end SingleLever;
