package UsersGuide "Users Guide"
annotation (DocumentationClass=true, classOrder={"GettingStarted","FAQ","ReleaseNotes","Contact","Literature","Support","About"},Documentation(info="<html>
<h3><font color=\"#008000\" size=5>Users Guide of \"Belts\" Library</font></h3>
</html>"));


class GettingStarted "Getting Started" 
  
  annotation (Documentation(info="<html>
 
<h3><font color=\"#008000\" size=5>Getting Started</font></h3>
 
 <p>
 This getting started guide describes how to build up the <a href=\"Modelica://Belts.Examples.SimpleBelt\">SimpleBelt</a> example that looks like this:
</p>
<p align=\"center\">
<IMG SRC=\"../Pics/simpleBelt.PNG\"
ALT=\"simple belt drive\">
</p>
 <p>
 You will find all parts you need for modelling a belt drive with this library in the <a href=\"Modelica://Belts.ModelElements\">ModelElements</a> package.
 Because this library is built upon the <a href=\"Modelica://Modelica.Mechanics.MultiBody\">MultiBody</a> library the first thing you should do is open a new model,
 drop a <a href=\"Modelica://Modelica.Mechanics.MultiBody.World\">World</a> element in the upper left corner and disable the world and gravity animation. 
 Having done this you can start modelling the belt drive.
</p>
<p>
The easiest way to model a belt drive is to begin with the pulleys. You will find two kinds of pulleys for modelling: <a href=\"Modelica://Belts.ModelElements.FixedPulley\">fixed pulleys</a> and <a href=\"Modelica://Belts.ModelElements.FreePulley\">free ones</a>.
The difference between both is that fixed pulleys have a fixed position while the free ones are able to move. For our simple belt drive the fixed pulleys are sufficient.
To set a pulley into the belt drive just drag it from the sidebar an drop it into the model area.
</p>
<p align=\"center\">
<IMG SRC=\"../Pics/GS_1.png\"
ALT=\"two pulleys on the model area\">
</p>
<p>
Now we have to set positions of the pulleys. 
Just double click on the pulleys and enter the desired position.
For <b>Pulley1</b> enter {0.3,0} for the position and 0.2 for the diameter and for <b>Pulley2</b> only {-0.2,0} as position.
If you want a pulley to be outside of the belt drive youve got to set the bool variable inside to false.
</p>
<p>
After setting all pulleys we take care of the belt.
A belt consists of two parts the <a href=\"Modelica://Belts.ModelElements.Span\">spans</a> and the <a href=\"Modelica://Belts.ModelElements.WrapAngle\">wrap angles</a> which have to alternate.
The best way is to start with a <a href=\"Modelica://Belts.ModelElements.WrapAngle\">wrap angle</a> placed around the pulley.
Its important to model counterclockwise because otherwise the direction of the belt would change and the inside option as well as the <a href=\"Modelica://Belts.ModelElements.WrapAngle\">wrap angles</a>  are not calculated properly.
To be sure that this wont happen just remember the rule: 
</p>
<p>
Always connect two components from <a href=\"Modelica://Belts.Interfaces.SpanConnector_b\">SpanConnector_b</a> to <a href=\"Modelica://Belts.Interfaces.SpanConnector_a\">SpanConnector_a</a>
</p>
<p>
From theory to practice. Drop a <a href=\"Modelica://Belts.ModelElements.WrapAngle\">wrap angle</a> into the model area. Place it next to <b>Pulley1</b> and connect its <a href=\"Modelica://Belts.Interfaces.WrapAngleConnector_a\">wrapAngleConnector</a> to the one from the pulley. 
Make sure that the <a href=\"Modelica://Belts.Interfaces.SpanConnector_b\">SpanConnector_b</a> ( marked with the red b)  is on the upper left side.
</p>
<p align=\"center\">
<IMG SRC=\"../Pics/GS_2.png\"
ALT=\"two pulleys and a wrapAngle on the model area\">
</p>
<p>
As mentioned <a href=\"Modelica://Belts.ModelElements.Span\">spans</a> and <a href=\"Modelica://Belts.ModelElements.WrapAngle\">wrap angles</a> have to alter. So the next part must be a <a href=\"Modelica://Belts.ModelElements.Span\">span</a>. Drop it on the model area and connect it to the <b>wrapAngle1</b>.
</p>
<p align=\"center\">
<IMG SRC=\"../Pics/GS_3.png\"
ALT=\"two pulleys, a wrapAngle and a Span on the model area\">
</p>
<p>
Now keep on connecting <a href=\"Modelica://Belts.ModelElements.Span\">spans</a> and <a href=\"Modelica://Belts.ModelElements.WrapAngle\">wrap angles</a> until the whole belt drive is complete.
</p>
<p align=\"center\">
<IMG SRC=\"../Pics/GS_4.png\"
ALT=\"the complete belt drive\">
</p>
You can now add elements from the <a href=\"Modelica://Modelica.Mechanics.Rotational\">Rotational</a> library to excite the drive with a torque or given motion.
</html>
"));
end GettingStarted;


 package FAQ "FAQ" 
  
  annotation (DocumentationClass=true, classOrder={"GeneralTopics","ModelingAndSimulation", "Animation"},Documentation(info="<html>
<h3><font color=\"#008000\" size=5>Users Guide of \"Belts\" Library</font></h3>
</html>"));
  
  class GeneralTopics "General Topics" 
    
    annotation (Documentation(info="<html>
<h3><font color=\"#008000\" size=5>General Topics:</font></h3>
 
<ul> 
<li>
Where can I get help?
<dl>
<dt><a href=\"http://www.ina.com\">INA</a> offers a <b>customer support</b> for the Belts library from <A HREF=\"mailto:beltslibrary@schaeffler.com\">beltslibrary@schaeffler.com</A>.</dt>
</dl>
 
<li>
Is there a mailing list for the <b>Belts</b> library?
<dl>
<dt>No, currently not.</dt>
</dl>
 
<li>
Is there also a support for non INA customers?
<dl>
<dt>Support for non INA customers cannot be offered.</dt>
</dl>
 
</ul>
 
</html>
"));
  end GeneralTopics;
  
  class ModelingAndSimulation "Modeling and Simulation" 
    
    annotation (Documentation(info="<html>
<h3><font color=\"#008000\" size=5>Modeling and Simulation:</font></h3>
 
<ul> 
<li>
Is there a recommended procedure to build up a belt drive model?
<dl>
<p>
The following steps describe the recommended procedure to assemble a belt drive. 
</p>
<ol> 
<li>Start the modeling by dragging and dropping the needed pulleys on the modeling space. 
<li>Decide on the <a href=\"Modelica://Belts.ContactModels\">contact model</a>. It is possible to choose between a <a href=\"Modelica://Belts.ContactModels.FlatBelt\">flat belt</a>,
 <a href=\"Modelica://Belts.ContactModels.VBelt\">V-belt</a> and <a href=\"Modelica://Belts.ContactModels.ToothBelt\">tooth belt</a>. The default is <a href=\"Modelica://Belts.ContactModels.FlatBelt\">flat belt</a>. 
<li>Position the pulleys at the desired spots.
<li>Optional: Build in the lever and the spring/damper combination.
<li>Add the wrap angles and connect them to the pulleys. 
<li>Drag and drop the span elements on the modeling space and connected them to the wrap angles counterclockwise.
<li>Enter the parameters of the belt, the pulleys, the lever and the spring/damper combination.
</ol> 
<p>
If you proceed in the assembling of your drive similar to the <a href=\"Modelica://Belts.UsersGuide.GettingStarted\">Getting Started</a> you should not have any problems. 
</p>
</dl>
</ul>
 
<ul> 
<li>
How do I set the initial position for a pulley which is not connected to \"ground\"?
<dl>
<dt>You can set initial conditions for a floating pulley in the parameter menu of the <a href=\"Modelica://Belts.ModelElements.FreePulley\">pulley</a>.</dt>
</dl>
 
<li>
How can I add a tensioner to my belt drive?
<dl>
<dt>The <b>Belts</b> library comes with a <a href=\"Modelica://Belts.ModelElements.DoubleLever\">tensioner arm assembly</a>. See the <a href=\"Modelica://Belts.Examples.PassengerCarAccessoryDrive\">accessory drive example</a> for more details</dt>
</dl>
 
<li>
How can I set the z-position of the belt drive?<dl>
<dt>The z-position of the drive can be set in the parameter menu of the <a href=\"Modelica://Belts.ModelElements.Span\">span</a> and <a href=\"Modelica://Belts.ModelElements.WrapAngle\">wrap angle</a>.</dt>
</dl>
 
<li>
I'm getting a strange layout in the Animation. The pulley order is right, but the wrap angles seem to be wrong?
<dl>
<dt>Be sure, that you have connected the spans and wrap angles in the correct order. Start counterclockwise and connect the spanConnector_b of the
first span to the spanConnector_a of the first wrap angle. After that connect the spanConnector_b of the first wrap angle to the 
spanConnector_a of the second span, and so on. For more details see <a href=\"Modelica://Belts.UsersGuide.GettingStarted\">Getting Started</a>.</dt>
</dl>
 
<li>
I changed the contact model of the pulleys to tooth belt, now an error is occurring, when the model is checked. What can I do?
<dl>
<dt>This problem occurs, if you have changed the friction coefficient in the contact model tab of the flat belt to an explicit figure instead of 
using the default <b>Belts.Defaults.Mu</b>. After switching to the tooth belt model the friction coefficient is still stored in the modelica 
text. However, in the tooth belt model the friction coefficient parameter is not available, thus the error occurs. You can handle this problem easily, 
delete \"mu=1,\" in the modelica text and your simulation will be able to start.</dt>
</dl>
</ul>
 
<ul>
<li>
At the start of the simulation I get excessive slip and the span forces go to zero. What's wrong with my model?
<dl>
<dt>This could be due to wrong initial condition of the <a href=\"Modelica://Belts.ModelElements.FreePulley\">pulley</a>. You need to set the initial rotary speed \"w_start\" in the parameters menu of the <a href=\"Modelica://Belts.ModelElements.FreePulley\">pulley</a>.</dt>
</dl>
 
<li>
My simulation is really slow. Is there anything I can do to reduce the simulation time?
<dl>
<p>
The following measures can be taken, however the animation will always be afflicted with a loss in animation quality. 
</p>
<ol>
<li>Set the parameter \"enableAnimation\" to \"false\" in the <a href=\"Modelica://Modelica.Mechanics.MultiBody.World\">world</a> object. 
The simulation will then be about 80% faster! Yet, no animation will be given out.
<li>If you are not interested in the vibrations of the belt: Set the parameter \"modeShapes\" to \"0\" in the <a href=\"Modelica://Belts.ModelElements.Span\">span</a> object. The simulation will be
about 70% faster! An animation will be given out, however no transversal vibrations in the belt will be animated.
<li>Set the parameter \"animationPoints\" to e.g. \"20\" in the <a href=\"Modelica://Belts.ModelElements.Span\">span</a> object. The simulation
 will be about 50% faster! However be aware, that the reduction of simulation time depends on the number of entered animation points.
 An animation will be given out, transversal vibrations will be animated in a lower resolution.
</ol>
<p>
You can decide for yourself which of these measures are appropriate to reduce the simulation time in your case. 
</p>
</dl>
 
<li>
Why are there some slide belt span vibrations at the start of every simulation?<dl>
<dt>The transversal degrees of freedom of the span vibration model need to start with a initial elongation. The initial value is set in the <a href=\"Modelica://Belts.Defaults\">Defaults</a> package.</dt>
</dl>
<li>
 
<li>
How many mode shapes do I need to simulate belt span vibrations?<dl>
<dt>The default value for the mode shapes of the <a href=\"Modelica://Belts.ModelElements.Span\">span</a> should be fine for most applications. If you are dealing with a large span length you should try out a higher values too.</dt>
</dl>
</ul>
 
</html>
"));
  end ModelingAndSimulation;
  
  class Animation "Animation" 
    
    annotation (Documentation(info="<html>
<h3><font color=\"#008000\" size=5>Animation:</font></h3>
 
<ul> 
<li>
Can I animate hubloads?
<dl>
<dt>Yes, you can enable the animation of the hubload vector in the \"Animation\" tab of the <a href=\"Modelica://Belts.ModelElements.FreePulley\">pulley</a>.</dt>
</dl>
<li>
 
Can I animate span forces?
<dl>
<dt>Yes, you can enable the animation of the span force vectors in the \"Animation\" tab of the <a href=\"Modelica://Belts.ModelElements.Span\">span</a>.</dt>
</dl>
 
<li>
Can I animate the torque on the pulley axis?<dl>
<dt>Yes, you can enable the animation of the load torque vector in the \"Animation\" tab of the <a href=\"Modelica://Belts.ModelElements.FreePulley\">pulley</a>.</dt>
</dl>
 
<li>
What is the use of the belt and pulley marker?
<dl>
<dt>The belt and pulley markers are used for displaying possible slippage between the belt and the different pulleys.</dt>
</dl>
 
<li>
Can I visualize belt slip?
<dl>
<dt>Yes, you can use the belt and pulley markers for visualizing belt slip. </dt>
</dl>
 
<li>
Can I change the color of the belt?
<dl>
<dt>No, at the moment it is not possible to change the color of the belt. </dt>
</dl>
 
<li>
Can I add a new pulley geometry for the animation?<dl>
<dt>Yes, your pulley visualizer should extend the <a href=\"Modelica://Belts.Interfaces.PartialPulleyShape\">PartialPulleyShape</a>. You will find your pulley visulalizer on the \"animation\" tab of the <a href=\"Modelica://Belts.ModelElements.FreePulley\">pulley</a>.</dt>
</dl>
<li>
 
<li>
Can I add my own belt shape to the animation?<dl>
<dt>Yes, your belt visulalizer should extend the <a href=\"Modelica://Belts.Interfaces.PartialBeltShape\">PartialBeltShape</a>. You will find your belt visulalizer on the \"animation\" tab in the <a href=\"Modelica://Belts.ModelElements.Span\">span</a> and <a href=\"Modelica://Belts.ModelElements.WrapAngle\">wrap angle</a>.</dt>
</dl>
<li> 
 
</ul>
 
</html>
"));
  end Animation;
  
 end FAQ;


class ReleaseNotes "Release Notes" 
annotation (DocumentationClass=true, Documentation(info="<html>
<h3><font color=\"#008000\" size=5>Release Notes</font></h3>
<h3><font color=\"#008000\">Version 1.0, 2007-10-29</font></h3>
<p>
This first release includes the following key features:
</p>
<ul>
<li> Pulleys with a fixed or fixed position in the x-y plane</li>
<li> Belt spans with linear stiffness</li>
<li> Transversal belt span vibration</li>
<li> Slip model based on friction equation according
to Eytelwein</li>
</ul>
<h3><font color=\"#008000\">Version 1.4, 2007-11-15</font></h3>
<ul>
<li> Component Belt is removed from the library. All belt parameter moved to the <a href=\"Modelica://Belts.ModelElements.Span\">span</a> and <a href=\"Modelica://Belts.ModelElements.WrapAngle\">wrap angle</a> models.</li>
<li> Documentation extended</li>
</ul>
<h3><font color=\"#008000\">Version 2.0, 2007-11-30</font></h3>
<p>
</p>
<ul>
<li> New Package <a href=\"Modelica://Belts.ContactModels\">ContactModels</a> contains models for <a href=\"Modelica://Belts.ContactModels.FlatBelt\">flat belt</a>, <a href=\"Modelica://Belts.ContactModels.VBelt\">V-belt</a> and <a href=\"Modelica://Belts.ContactModels.ToothBelt\">tooth belt</a> contact.</li>
<li> New interface <a href=\"Modelica://Belts.Interfaces.PartialContactModel\">PartialContactModel</a> for the pulley belt contact. Users can now implement own contact models by extending this interface model.</li>
</ul>
<h3><font color=\"#008000\">Version 2.2, 2008-01-14</font></h3>
<p>
</p>
<ul>
<li> Library update to <b>Modelica Standard Library</b> version 2.2.2.</li>
<li> Documentation extended</li>
<li> License changed</li>
</ul> 
</html>"));
end ReleaseNotes;


class Updates "Updates" 
  
  annotation (Documentation(info="<html>
<h3><font color=\"#008000\" size=5>Library Updates</font></h3>
<dl>
<dt>The latest version of this library is available for download. Click <a href=\"http://www.ina.com/content.ina.de/en/branches/automotive/engine_systems/mot3600/mot3600.jsp\">here</a> for more information.
</dl>
</html>
"));
end Updates;


class Contact "Contact" 
  annotation (Documentation(info="<html>
<h3><font color=\"#008000\" size=5>Contact</font></h3>
<dl>
<dt><b>Main Author:</b>
<br>
<dd>
<br>Frank Rettig<br>
    Schaeffler KG<br>
    Industrie Str. 1-3<br>
    D-91074 Herzogenaurach<br>
    Germany<br>
    email: <A HREF=\"mailto:frank.rettig@schaeffler.com\">frank.rettig@schaeffler.com</A><br>
</dl>
<dl>
<br><br>
<dt><b>Co Authors:</b>
<dd>
<br>Florian Werner<br>
    Schaeffler KG<br>
    Industrie Str. 1-3<br>
    D-91074 Herzogenaurach<br>
    Germany<br>
<br>
<dd>Jrgen Hanke<br>
    Schaeffler KG<br>
    Industrie Str. 1-3<br>
    D-91074 Herzogenaurach<br>
    Germany<br>
<dd>
<br>Markus Popp<br>
    Schaeffler KG<br>
    Industrie Str. 1-3<br>
    D-91074 Herzogenaurach<br>
    Germany<br>
<br>
</dl>
</html>
"));
end Contact;


class Literature "Literature" 
  annotation (Documentation(info="<html>
<h3><font color=\"#008000\" size=5>Literature</font></h3>
<ul>
<dt>[1] Fritzer, A.:</dt>
<dd> <b>Entwicklung von Modellen und Berechnungsverfahren zur Bestimmung der Schwingungsbelastungen in Steuer- und Hilfsantrieben von Verbrennungsmotoren, Abschlubericht des Forschungsvorhabens \"Steuerungsantrieb\", AIF-Nr. 7470, Forschungsvereinigung Verbrennungskraftmaschinen e.V., Frankfurt/Main 1991
</b>
</dd>
<br>
<dt>[2] Herrmann, R.-J.:</dt>
<dd> <b>Ermittlung und systematische anwenderorientierte Darstellung von dynamischen und quasistatischen Kennwerten von Keil-, Flach- und Zahnriemen-Getrieben, Abschlubericht des Forschungsvorhabens \"Riemenkennwerte\", AIF-Nr. 7453, Forschungskuratorium Maschinenbau e.V., Frankfurt/Main 1991
</b>.
</dd>
<br>
<dt>[3] Funk, W.:</dt>
<dd><b>Zugmittelgetriebe. Springer Verlag. Berlin. 1995</b><br>
</dd>
<br>
<dt>[4] Press, W. H.; et al.:</dt
<dd><b>Numerical Recipes. Cambridge University Press. Cambridge 1986</b><br>
</dd>
<br>
<dt>[5] Solfrank, Peter and Kelm, Peter:</dt
<dd><b><a href=\"..\UsersGuide\Dynamic Simulation of Automobile Accessory Drives.pdf\">
<b>Dynamic Simulation of Automobile Accessory Drives</b></a>. Herzogenaurach 1999.</b><br>
</dd>
<br>
<dt>[6] Kelm, Peter and Rettig, Frank:</dt
<dd><b>Analysis of Transversal Belt Vibrations in Passenger Car Accessory Drives. Herzogenaurach 2003.</b><br>
</dd>
</ul>
</html>
"));
end Literature;


class Support "Support" 
  
annotation (DocumentationClass=true, Documentation(info="<html>
<h3><font color=\"#008000\" size=5>Support</font></h3>
<p>
   <b>In combination with customer projects:</b><br>
<a href=\"http://www.ina.com\">INA</a> offers support for this library from <A HREF=\"mailto:beltslibrary@schaeffler.com\">beltslibrary@schaeffler.com</A>.
<p>
</html>"));
end Support;


class About "About" 
annotation (DocumentationClass=true, Documentation(info="<html>
<h3><font color=\"#008000\" size=5>About \"Belts\" Library</font></h3>
<p>
<img src=\"../Pics/INA.gif\">
</p>
<p>
   Modelica Belts Library by Schaeffler KG<br>
   version 2.0<br>
<p>
<p>
   For more information visit <a href=\"http://www.ina.com\">
   www.ina.com</a>.
</p>
<p>
Copyright &copy; 2007, Schaeffler KG, Herzogenaurach
</p> 
</html>"));
end About;


class License "License" 
  
annotation (DocumentationClass=true, Documentation(info="<html>
<h3><font color=\"#008000\" size=5>License</font></h3>
 
<p>
The license of this library is the <a href=\"Modelica://Modelica.UsersGuide.ModelicaLicense\">Modelica license</a>, with the following restriction: Modifying the library requires that the modified 
library is provided under the same license condition as this library and is made available in source code form.
</p>
 
 
 
 
 
</html>"));
end License;
end UsersGuide;
