model Span "Visualizes the Span" 
  extends Modelica.Icons.Library;
  import Modelica.Math.*;
  import SI = Modelica.SIunits;
  import Modelica.Constants.pi;
  input SI.Position ContactPoint_1[3] = {0,0, 0};
  input SI.Position ContactPoint_2[3] = {0,0, 0};
  input SI.Length h=0.005 "belt hight";
  input SI.Radius b=0.03 "pulley width";
  input Integer PullyDirection_a;
  input Integer PullyDirection_b;
  Real ampl[:] = {0,0,0};
  parameter Real shape[:,:]= {{0,0.5},{0,-0.5},{1,-0.5},{1,0.5}} 
    "belt shape used for animation";
  parameter Integer s = size(shape,1)+1;
  parameter Integer numPnts=100 "points used to visualize the span";
  extends Belts.Interfaces.PartialParameterizedSurface(  final nu=numPnts, final nv=s);
  
protected 
  Real u;
  Real v;
  Real nx;
  Real ny;
  Real temph;
  Real Length;
  Real a;
  Real t;
  
algorithm 
  // calculating the normal vector to the span
  nx :=(ContactPoint_2[2] - ContactPoint_1[2])*(-1);
  ny :=ContactPoint_2[1] - ContactPoint_1[1];
  // Length between the contact points
  Length:=sqrt((ContactPoint_2[1]-ContactPoint_1[1])^2+(ContactPoint_2[2]-ContactPoint_1[2])^2);
  
  for j in 1:nu loop
   // linear interpolation  betweeen the contact points
   u:=ContactPoint_1[1] + (j - 1)*(ContactPoint_2[1] - ContactPoint_1[1])/(nu- 1);
   v:=ContactPoint_1[2] + (j - 1)*(ContactPoint_2[2] - ContactPoint_1[2])/(nu- 1);
   // the distence from contact point 1 to interpolation point
   t:=sqrt((u-ContactPoint_1[1])^2 + (v-ContactPoint_1[2])^2);
   // sum the amplitudes of the transversal vibrations of the Span
   a:=0;
   for i in 1:size(ampl,1) loop
     a:=a+ ampl[i]*sin(i*pi*t/Length);
   end for;
   // adding the amplitide to the interpolatet point in normal direction
   u:=u + a/sqrt(nx^2 + ny^2)*nx;
   v:=v + a/sqrt(nx^2 + ny^2)*ny;
    
    // --------------------------------------------------------------------------------- draw shape
   for i in 1:(s-1) loop
      
        x[j, i] := u + shape[i,1]*h/sqrt(nx^2+ny^2)* nx;
        y[j, i] := v + shape[i,1]*h/sqrt(nx^2+ny^2)* ny;
        z[j, i] := shape[i,2]*b  + ContactPoint_1[3];
      
    end for;
  end for;
  
  // --------------------------------------------------------------------------------- adapt belt and pulley   
  if  (PullyDirection_a + PullyDirection_b) == 2 then       // both pulleys outside
  for j in 1:nu loop
      for i in 1:nv loop
          x[j, i]:=x[j, i] - h/sqrt(nx^2 + ny^2)*nx;
          y[j, i]:=y[j, i] - h/sqrt(nx^2 + ny^2)*ny;
      end for;
    end for;
  elseif (PullyDirection_a + PullyDirection_b) == -2 then   // both pulleys inside
    // Nichts zu Tun
  else
   if PullyDirection_a == -1 then                            // first pulley inside
      for j in 1:nu loop
         temph:=h-(j - 1)/(nu - 1)*h;
        for i in 1:nv loop
          x[j, i]:=x[j, i] - temph/sqrt(nx^2 + ny^2)*nx;
          y[j, i]:=y[j, i] - temph/sqrt(nx^2 + ny^2)*ny;
        end for;
      end for;
    end if;
    if PullyDirection_b == -1 then  // Second pulley inside
      for j in 1:nu loop
         temph:=(j - 1)/(nu - 1)*h;
        for i in 1:nv loop
          x[j, i]:=x[j, i] - temph/sqrt(nx^2 + ny^2)*nx;
          y[j, i]:=y[j, i] - temph/sqrt(nx^2 + ny^2)*ny;
        end for;
      end for;
    end if;
  end if;
   // last point of profil is first point of profil
  x[:,s] := x[:,1];
  y[:,s] := y[:,1];
  z[:,s] := z[:,1];
end Span;
