model WrapAngle "Visualizes the WrapAngle" 
  
  extends Modelica.Icons.Library;
  
  import SI = Modelica.SIunits;
  import Modelica.Constants.pi;
  input SI.Radius ri=0.075 "pulley radius";
  input SI.Length h=0.005 "belt hight";
  input SI.Radius b=0.03 "pulley width";
  input SI.Angle startAngle= -pi/2 "useful to draw only a slice of the torus";
  input SI.Angle stopAngle= pi/2 "useful to draw only a slice of the torus";
  input SI.Position PulleyPosition[3] = {0,0, 0};
  input Modelica.Mechanics.MultiBody.Types.SpecularCoefficient 
    SpecularCoefficient =              0.3;
  input Modelica.Mechanics.MultiBody.Types.Color Color = {255,255,255};
  input Integer PullyDirection=-1;
  parameter Real shape[:,:]= {{0.9,0.5*6/6},{0,0.5*5/6},{0.9,0.5*4/6},{0,0.5*3/6},{0.9,0.5*2/6},{0,0.5*1/6},{0.9,0.5*0/6},{0,-0.5*1/6},{0.9,-0.5*2/6},{0,-0.5*3/6},{0.9,-0.5*4/6},{0,-0.5*5/6},{0.9,-0.5*6/6},{1,-0.5},{1,0.5}} 
    "belt shape used for animation";
  parameter Integer s = size(shape,1)+1;
  extends Belts.Interfaces.PartialParameterizedSurface(  final nu=31, final nv=s);
  
protected 
  Real u;
  Real v;
  Real nx;
  Real ny;
  Real sp[s-1];
  
algorithm 
  if PullyDirection==1 then   // pully is outside
    for i in 1:(s-1) loop
      sp[i]:=1 - shape[i, 1];  // mirroring the belt profile
    end for;
  else                        // pully is inside
  sp:=shape[:, 1];
  end if;
  
  for i in 1:nu loop
      u:=ri*cos(startAngle + (i - 1)*(stopAngle - startAngle)/(nu - 1)) +
      PulleyPosition[1];
      v:=ri*sin(startAngle + (i - 1)*(stopAngle - startAngle)/(nu - 1)) +
      PulleyPosition[2];
      nx:=u - PulleyPosition[1];
      ny:=v - PulleyPosition[2];
    // making the profil
    for j in 1:(s-1) loop
      x[i, j] := u + sp[j]*h/sqrt(nx^2+ny^2)* nx;
      y[i, j] := v + sp[j]*h/sqrt(nx^2+ny^2)* ny;
      z[i, j] := shape[j,2]*b  + PulleyPosition[3];
    end for;
  end for;
  // last point of profil is first point of profil
  x[:,s] := x[:,1];
  y[:,s] := y[:,1];
  z[:,s] := z[:,1];
  
  annotation (Documentation(info="<html>
 
</html>"));
end WrapAngle;
